{-|
Module      : Monomer.Graphics.RemixIcon
Copyright   : (c) 2018 Francisco Vallarino
License     : BSD-3-Clause (see the LICENSE file)
Maintainer  : fjvallarino@gmail.com
Stability   : experimental
Portability : non-portable

Utility functions to retrieve the Unicode code point of a Remix Font using its
representative name. These code points can be used in labels or buttons to show
icons instead of regular text.

Make sure to load the remixicon.ttf font in your application and set 'textFont'
in the corresponding widget.

Existing icons can be browsed in https://remixicon.com.

The name has to be updated by adding a _remix_ prefix, applying capital case and
removing dashes. For example, _"delete-bin"_ should be transformed to
_"remixDeleteBin"_. Also note that most icons have line and fill versions, so
you will also need to include that (for example, _"remixDeleteBinLine"_ or
_"remixDeleteBinFill"_).
-}
{-# LANGUAGE BinaryLiterals #-}

module Monomer.Graphics.RemixIcon where

import Data.Text (Text)

import qualified Data.Text as T

toGlyph :: Int -> Text
toGlyph = T.singleton . toEnum

remix24HoursFill = toGlyph 0XEA01
remix24HoursLine = toGlyph 0XEA02
remix4kFill = toGlyph 0XEA03
remix4kLine = toGlyph 0XEA04
remixAB = toGlyph 0XEA05
remixAccountBoxFill = toGlyph 0XEA06
remixAccountBoxLine = toGlyph 0XEA07
remixAccountCircleFill = toGlyph 0XEA08
remixAccountCircleLine = toGlyph 0XEA09
remixAccountPinBoxFill = toGlyph 0XEA0A
remixAccountPinBoxLine = toGlyph 0XEA0B
remixAccountPinCircleFill = toGlyph 0XEA0C
remixAccountPinCircleLine = toGlyph 0XEA0D
remixAddBoxFill = toGlyph 0XEA0E
remixAddBoxLine = toGlyph 0XEA0F
remixAddCircleFill = toGlyph 0XEA10
remixAddCircleLine = toGlyph 0XEA11
remixAddFill = toGlyph 0XEA12
remixAddLine = toGlyph 0XEA13
remixAdminFill = toGlyph 0XEA14
remixAdminLine = toGlyph 0XEA15
remixAdvertisementFill = toGlyph 0XEA16
remixAdvertisementLine = toGlyph 0XEA17
remixAirplayFill = toGlyph 0XEA18
remixAirplayLine = toGlyph 0XEA19
remixAlarmFill = toGlyph 0XEA1A
remixAlarmLine = toGlyph 0XEA1B
remixAlarmWarningFill = toGlyph 0XEA1C
remixAlarmWarningLine = toGlyph 0XEA1D
remixAlbumFill = toGlyph 0XEA1E
remixAlbumLine = toGlyph 0XEA1F
remixAlertFill = toGlyph 0XEA20
remixAlertLine = toGlyph 0XEA21
remixAliensFill = toGlyph 0XEA22
remixAliensLine = toGlyph 0XEA23
remixAlignBottom = toGlyph 0XEA24
remixAlignCenter = toGlyph 0XEA25
remixAlignJustify = toGlyph 0XEA26
remixAlignLeft = toGlyph 0XEA27
remixAlignRight = toGlyph 0XEA28
remixAlignTop = toGlyph 0XEA29
remixAlignVertically = toGlyph 0XEA2A
remixAlipayFill = toGlyph 0XEA2B
remixAlipayLine = toGlyph 0XEA2C
remixAmazonFill = toGlyph 0XEA2D
remixAmazonLine = toGlyph 0XEA2E
remixAnchorFill = toGlyph 0XEA2F
remixAnchorLine = toGlyph 0XEA30
remixAncientGateFill = toGlyph 0XEA31
remixAncientGateLine = toGlyph 0XEA32
remixAncientPavilionFill = toGlyph 0XEA33
remixAncientPavilionLine = toGlyph 0XEA34
remixAndroidFill = toGlyph 0XEA35
remixAndroidLine = toGlyph 0XEA36
remixAngularjsFill = toGlyph 0XEA37
remixAngularjsLine = toGlyph 0XEA38
remixAnticlockwise2Fill = toGlyph 0XEA39
remixAnticlockwise2Line = toGlyph 0XEA3A
remixAnticlockwiseFill = toGlyph 0XEA3B
remixAnticlockwiseLine = toGlyph 0XEA3C
remixAppStoreFill = toGlyph 0XEA3D
remixAppStoreLine = toGlyph 0XEA3E
remixAppleFill = toGlyph 0XEA3F
remixAppleLine = toGlyph 0XEA40
remixApps2Fill = toGlyph 0XEA41
remixApps2Line = toGlyph 0XEA42
remixAppsFill = toGlyph 0XEA43
remixAppsLine = toGlyph 0XEA44
remixArchiveDrawerFill = toGlyph 0XEA45
remixArchiveDrawerLine = toGlyph 0XEA46
remixArchiveFill = toGlyph 0XEA47
remixArchiveLine = toGlyph 0XEA48
remixArrowDownCircleFill = toGlyph 0XEA49
remixArrowDownCircleLine = toGlyph 0XEA4A
remixArrowDownFill = toGlyph 0XEA4B
remixArrowDownLine = toGlyph 0XEA4C
remixArrowDownSFill = toGlyph 0XEA4D
remixArrowDownSLine = toGlyph 0XEA4E
remixArrowDropDownFill = toGlyph 0XEA4F
remixArrowDropDownLine = toGlyph 0XEA50
remixArrowDropLeftFill = toGlyph 0XEA51
remixArrowDropLeftLine = toGlyph 0XEA52
remixArrowDropRightFill = toGlyph 0XEA53
remixArrowDropRightLine = toGlyph 0XEA54
remixArrowDropUpFill = toGlyph 0XEA55
remixArrowDropUpLine = toGlyph 0XEA56
remixArrowGoBackFill = toGlyph 0XEA57
remixArrowGoBackLine = toGlyph 0XEA58
remixArrowGoForwardFill = toGlyph 0XEA59
remixArrowGoForwardLine = toGlyph 0XEA5A
remixArrowLeftCircleFill = toGlyph 0XEA5B
remixArrowLeftCircleLine = toGlyph 0XEA5C
remixArrowLeftDownFill = toGlyph 0XEA5D
remixArrowLeftDownLine = toGlyph 0XEA5E
remixArrowLeftFill = toGlyph 0XEA5F
remixArrowLeftLine = toGlyph 0XEA60
remixArrowLeftRightFill = toGlyph 0XEA61
remixArrowLeftRightLine = toGlyph 0XEA62
remixArrowLeftSFill = toGlyph 0XEA63
remixArrowLeftSLine = toGlyph 0XEA64
remixArrowLeftUpFill = toGlyph 0XEA65
remixArrowLeftUpLine = toGlyph 0XEA66
remixArrowRightCircleFill = toGlyph 0XEA67
remixArrowRightCircleLine = toGlyph 0XEA68
remixArrowRightDownFill = toGlyph 0XEA69
remixArrowRightDownLine = toGlyph 0XEA6A
remixArrowRightFill = toGlyph 0XEA6B
remixArrowRightLine = toGlyph 0XEA6C
remixArrowRightSFill = toGlyph 0XEA6D
remixArrowRightSLine = toGlyph 0XEA6E
remixArrowRightUpFill = toGlyph 0XEA6F
remixArrowRightUpLine = toGlyph 0XEA70
remixArrowUpCircleFill = toGlyph 0XEA71
remixArrowUpCircleLine = toGlyph 0XEA72
remixArrowUpDownFill = toGlyph 0XEA73
remixArrowUpDownLine = toGlyph 0XEA74
remixArrowUpFill = toGlyph 0XEA75
remixArrowUpLine = toGlyph 0XEA76
remixArrowUpSFill = toGlyph 0XEA77
remixArrowUpSLine = toGlyph 0XEA78
remixArtboard2Fill = toGlyph 0XEA79
remixArtboard2Line = toGlyph 0XEA7A
remixArtboardFill = toGlyph 0XEA7B
remixArtboardLine = toGlyph 0XEA7C
remixArticleFill = toGlyph 0XEA7D
remixArticleLine = toGlyph 0XEA7E
remixAspectRatioFill = toGlyph 0XEA7F
remixAspectRatioLine = toGlyph 0XEA80
remixAsterisk = toGlyph 0XEA81
remixAtFill = toGlyph 0XEA82
remixAtLine = toGlyph 0XEA83
remixAttachment2 = toGlyph 0XEA84
remixAttachmentFill = toGlyph 0XEA85
remixAttachmentLine = toGlyph 0XEA86
remixAuctionFill = toGlyph 0XEA87
remixAuctionLine = toGlyph 0XEA88
remixAwardFill = toGlyph 0XEA89
remixAwardLine = toGlyph 0XEA8A
remixBaiduFill = toGlyph 0XEA8B
remixBaiduLine = toGlyph 0XEA8C
remixBallPenFill = toGlyph 0XEA8D
remixBallPenLine = toGlyph 0XEA8E
remixBankCard2Fill = toGlyph 0XEA8F
remixBankCard2Line = toGlyph 0XEA90
remixBankCardFill = toGlyph 0XEA91
remixBankCardLine = toGlyph 0XEA92
remixBankFill = toGlyph 0XEA93
remixBankLine = toGlyph 0XEA94
remixBarChart2Fill = toGlyph 0XEA95
remixBarChart2Line = toGlyph 0XEA96
remixBarChartBoxFill = toGlyph 0XEA97
remixBarChartBoxLine = toGlyph 0XEA98
remixBarChartFill = toGlyph 0XEA99
remixBarChartGroupedFill = toGlyph 0XEA9A
remixBarChartGroupedLine = toGlyph 0XEA9B
remixBarChartHorizontalFill = toGlyph 0XEA9C
remixBarChartHorizontalLine = toGlyph 0XEA9D
remixBarChartLine = toGlyph 0XEA9E
remixBarcodeBoxFill = toGlyph 0XEA9F
remixBarcodeBoxLine = toGlyph 0XEAA0
remixBarcodeFill = toGlyph 0XEAA1
remixBarcodeLine = toGlyph 0XEAA2
remixBarricadeFill = toGlyph 0XEAA3
remixBarricadeLine = toGlyph 0XEAA4
remixBaseStationFill = toGlyph 0XEAA5
remixBaseStationLine = toGlyph 0XEAA6
remixBasketballFill = toGlyph 0XEAA7
remixBasketballLine = toGlyph 0XEAA8
remixBattery2ChargeFill = toGlyph 0XEAA9
remixBattery2ChargeLine = toGlyph 0XEAAA
remixBattery2Fill = toGlyph 0XEAAB
remixBattery2Line = toGlyph 0XEAAC
remixBatteryChargeFill = toGlyph 0XEAAD
remixBatteryChargeLine = toGlyph 0XEAAE
remixBatteryFill = toGlyph 0XEAAF
remixBatteryLine = toGlyph 0XEAB0
remixBatteryLowFill = toGlyph 0XEAB1
remixBatteryLowLine = toGlyph 0XEAB2
remixBatterySaverFill = toGlyph 0XEAB3
remixBatterySaverLine = toGlyph 0XEAB4
remixBatteryShareFill = toGlyph 0XEAB5
remixBatteryShareLine = toGlyph 0XEAB6
remixBearSmileFill = toGlyph 0XEAB7
remixBearSmileLine = toGlyph 0XEAB8
remixBehanceFill = toGlyph 0XEAB9
remixBehanceLine = toGlyph 0XEABA
remixBellFill = toGlyph 0XEABB
remixBellLine = toGlyph 0XEABC
remixBikeFill = toGlyph 0XEABD
remixBikeLine = toGlyph 0XEABE
remixBilibiliFill = toGlyph 0XEABF
remixBilibiliLine = toGlyph 0XEAC0
remixBillFill = toGlyph 0XEAC1
remixBillLine = toGlyph 0XEAC2
remixBilliardsFill = toGlyph 0XEAC3
remixBilliardsLine = toGlyph 0XEAC4
remixBitCoinFill = toGlyph 0XEAC5
remixBitCoinLine = toGlyph 0XEAC6
remixBlazeFill = toGlyph 0XEAC7
remixBlazeLine = toGlyph 0XEAC8
remixBluetoothConnectFill = toGlyph 0XEAC9
remixBluetoothConnectLine = toGlyph 0XEACA
remixBluetoothFill = toGlyph 0XEACB
remixBluetoothLine = toGlyph 0XEACC
remixBlurOffFill = toGlyph 0XEACD
remixBlurOffLine = toGlyph 0XEACE
remixBodyScanFill = toGlyph 0XEACF
remixBodyScanLine = toGlyph 0XEAD0
remixBold = toGlyph 0XEAD1
remixBook2Fill = toGlyph 0XEAD2
remixBook2Line = toGlyph 0XEAD3
remixBook3Fill = toGlyph 0XEAD4
remixBook3Line = toGlyph 0XEAD5
remixBookFill = toGlyph 0XEAD6
remixBookLine = toGlyph 0XEAD7
remixBookMarkFill = toGlyph 0XEAD8
remixBookMarkLine = toGlyph 0XEAD9
remixBookOpenFill = toGlyph 0XEADA
remixBookOpenLine = toGlyph 0XEADB
remixBookReadFill = toGlyph 0XEADC
remixBookReadLine = toGlyph 0XEADD
remixBookletFill = toGlyph 0XEADE
remixBookletLine = toGlyph 0XEADF
remixBookmark2Fill = toGlyph 0XEAE0
remixBookmark2Line = toGlyph 0XEAE1
remixBookmark3Fill = toGlyph 0XEAE2
remixBookmark3Line = toGlyph 0XEAE3
remixBookmarkFill = toGlyph 0XEAE4
remixBookmarkLine = toGlyph 0XEAE5
remixBoxingFill = toGlyph 0XEAE6
remixBoxingLine = toGlyph 0XEAE7
remixBracesFill = toGlyph 0XEAE8
remixBracesLine = toGlyph 0XEAE9
remixBracketsFill = toGlyph 0XEAEA
remixBracketsLine = toGlyph 0XEAEB
remixBriefcase2Fill = toGlyph 0XEAEC
remixBriefcase2Line = toGlyph 0XEAED
remixBriefcase3Fill = toGlyph 0XEAEE
remixBriefcase3Line = toGlyph 0XEAEF
remixBriefcase4Fill = toGlyph 0XEAF0
remixBriefcase4Line = toGlyph 0XEAF1
remixBriefcase5Fill = toGlyph 0XEAF2
remixBriefcase5Line = toGlyph 0XEAF3
remixBriefcaseFill = toGlyph 0XEAF4
remixBriefcaseLine = toGlyph 0XEAF5
remixBringForward = toGlyph 0XEAF6
remixBringToFront = toGlyph 0XEAF7
remixBroadcastFill = toGlyph 0XEAF8
remixBroadcastLine = toGlyph 0XEAF9
remixBrush2Fill = toGlyph 0XEAFA
remixBrush2Line = toGlyph 0XEAFB
remixBrush3Fill = toGlyph 0XEAFC
remixBrush3Line = toGlyph 0XEAFD
remixBrush4Fill = toGlyph 0XEAFE
remixBrush4Line = toGlyph 0XEAFF
remixBrushFill = toGlyph 0XEB00
remixBrushLine = toGlyph 0XEB01
remixBubbleChartFill = toGlyph 0XEB02
remixBubbleChartLine = toGlyph 0XEB03
remixBug2Fill = toGlyph 0XEB04
remixBug2Line = toGlyph 0XEB05
remixBugFill = toGlyph 0XEB06
remixBugLine = toGlyph 0XEB07
remixBuilding2Fill = toGlyph 0XEB08
remixBuilding2Line = toGlyph 0XEB09
remixBuilding3Fill = toGlyph 0XEB0A
remixBuilding3Line = toGlyph 0XEB0B
remixBuilding4Fill = toGlyph 0XEB0C
remixBuilding4Line = toGlyph 0XEB0D
remixBuildingFill = toGlyph 0XEB0E
remixBuildingLine = toGlyph 0XEB0F
remixBus2Fill = toGlyph 0XEB10
remixBus2Line = toGlyph 0XEB11
remixBusFill = toGlyph 0XEB12
remixBusLine = toGlyph 0XEB13
remixBusWifiFill = toGlyph 0XEB14
remixBusWifiLine = toGlyph 0XEB15
remixCactusFill = toGlyph 0XEB16
remixCactusLine = toGlyph 0XEB17
remixCake2Fill = toGlyph 0XEB18
remixCake2Line = toGlyph 0XEB19
remixCake3Fill = toGlyph 0XEB1A
remixCake3Line = toGlyph 0XEB1B
remixCakeFill = toGlyph 0XEB1C
remixCakeLine = toGlyph 0XEB1D
remixCalculatorFill = toGlyph 0XEB1E
remixCalculatorLine = toGlyph 0XEB1F
remixCalendar2Fill = toGlyph 0XEB20
remixCalendar2Line = toGlyph 0XEB21
remixCalendarCheckFill = toGlyph 0XEB22
remixCalendarCheckLine = toGlyph 0XEB23
remixCalendarEventFill = toGlyph 0XEB24
remixCalendarEventLine = toGlyph 0XEB25
remixCalendarFill = toGlyph 0XEB26
remixCalendarLine = toGlyph 0XEB27
remixCalendarTodoFill = toGlyph 0XEB28
remixCalendarTodoLine = toGlyph 0XEB29
remixCamera2Fill = toGlyph 0XEB2A
remixCamera2Line = toGlyph 0XEB2B
remixCamera3Fill = toGlyph 0XEB2C
remixCamera3Line = toGlyph 0XEB2D
remixCameraFill = toGlyph 0XEB2E
remixCameraLensFill = toGlyph 0XEB2F
remixCameraLensLine = toGlyph 0XEB30
remixCameraLine = toGlyph 0XEB31
remixCameraOffFill = toGlyph 0XEB32
remixCameraOffLine = toGlyph 0XEB33
remixCameraSwitchFill = toGlyph 0XEB34
remixCameraSwitchLine = toGlyph 0XEB35
remixCapsuleFill = toGlyph 0XEB36
remixCapsuleLine = toGlyph 0XEB37
remixCarFill = toGlyph 0XEB38
remixCarLine = toGlyph 0XEB39
remixCarWashingFill = toGlyph 0XEB3A
remixCarWashingLine = toGlyph 0XEB3B
remixCaravanFill = toGlyph 0XEB3C
remixCaravanLine = toGlyph 0XEB3D
remixCastFill = toGlyph 0XEB3E
remixCastLine = toGlyph 0XEB3F
remixCellphoneFill = toGlyph 0XEB40
remixCellphoneLine = toGlyph 0XEB41
remixCelsiusFill = toGlyph 0XEB42
remixCelsiusLine = toGlyph 0XEB43
remixCentosFill = toGlyph 0XEB44
remixCentosLine = toGlyph 0XEB45
remixCharacterRecognitionFill = toGlyph 0XEB46
remixCharacterRecognitionLine = toGlyph 0XEB47
remixChargingPile2Fill = toGlyph 0XEB48
remixChargingPile2Line = toGlyph 0XEB49
remixChargingPileFill = toGlyph 0XEB4A
remixChargingPileLine = toGlyph 0XEB4B
remixChat1Fill = toGlyph 0XEB4C
remixChat1Line = toGlyph 0XEB4D
remixChat2Fill = toGlyph 0XEB4E
remixChat2Line = toGlyph 0XEB4F
remixChat3Fill = toGlyph 0XEB50
remixChat3Line = toGlyph 0XEB51
remixChat4Fill = toGlyph 0XEB52
remixChat4Line = toGlyph 0XEB53
remixChatCheckFill = toGlyph 0XEB54
remixChatCheckLine = toGlyph 0XEB55
remixChatDeleteFill = toGlyph 0XEB56
remixChatDeleteLine = toGlyph 0XEB57
remixChatDownloadFill = toGlyph 0XEB58
remixChatDownloadLine = toGlyph 0XEB59
remixChatFollowUpFill = toGlyph 0XEB5A
remixChatFollowUpLine = toGlyph 0XEB5B
remixChatForwardFill = toGlyph 0XEB5C
remixChatForwardLine = toGlyph 0XEB5D
remixChatHeartFill = toGlyph 0XEB5E
remixChatHeartLine = toGlyph 0XEB5F
remixChatHistoryFill = toGlyph 0XEB60
remixChatHistoryLine = toGlyph 0XEB61
remixChatNewFill = toGlyph 0XEB62
remixChatNewLine = toGlyph 0XEB63
remixChatOffFill = toGlyph 0XEB64
remixChatOffLine = toGlyph 0XEB65
remixChatPollFill = toGlyph 0XEB66
remixChatPollLine = toGlyph 0XEB67
remixChatPrivateFill = toGlyph 0XEB68
remixChatPrivateLine = toGlyph 0XEB69
remixChatQuoteFill = toGlyph 0XEB6A
remixChatQuoteLine = toGlyph 0XEB6B
remixChatSettingsFill = toGlyph 0XEB6C
remixChatSettingsLine = toGlyph 0XEB6D
remixChatSmile2Fill = toGlyph 0XEB6E
remixChatSmile2Line = toGlyph 0XEB6F
remixChatSmile3Fill = toGlyph 0XEB70
remixChatSmile3Line = toGlyph 0XEB71
remixChatSmileFill = toGlyph 0XEB72
remixChatSmileLine = toGlyph 0XEB73
remixChatUploadFill = toGlyph 0XEB74
remixChatUploadLine = toGlyph 0XEB75
remixChatVoiceFill = toGlyph 0XEB76
remixChatVoiceLine = toGlyph 0XEB77
remixCheckDoubleFill = toGlyph 0XEB78
remixCheckDoubleLine = toGlyph 0XEB79
remixCheckFill = toGlyph 0XEB7A
remixCheckLine = toGlyph 0XEB7B
remixCheckboxBlankCircleFill = toGlyph 0XEB7C
remixCheckboxBlankCircleLine = toGlyph 0XEB7D
remixCheckboxBlankFill = toGlyph 0XEB7E
remixCheckboxBlankLine = toGlyph 0XEB7F
remixCheckboxCircleFill = toGlyph 0XEB80
remixCheckboxCircleLine = toGlyph 0XEB81
remixCheckboxFill = toGlyph 0XEB82
remixCheckboxIndeterminateFill = toGlyph 0XEB83
remixCheckboxIndeterminateLine = toGlyph 0XEB84
remixCheckboxLine = toGlyph 0XEB85
remixCheckboxMultipleBlankFill = toGlyph 0XEB86
remixCheckboxMultipleBlankLine = toGlyph 0XEB87
remixCheckboxMultipleFill = toGlyph 0XEB88
remixCheckboxMultipleLine = toGlyph 0XEB89
remixChinaRailwayFill = toGlyph 0XEB8A
remixChinaRailwayLine = toGlyph 0XEB8B
remixChromeFill = toGlyph 0XEB8C
remixChromeLine = toGlyph 0XEB8D
remixClapperboardFill = toGlyph 0XEB8E
remixClapperboardLine = toGlyph 0XEB8F
remixClipboardFill = toGlyph 0XEB90
remixClipboardLine = toGlyph 0XEB91
remixClockwise2Fill = toGlyph 0XEB92
remixClockwise2Line = toGlyph 0XEB93
remixClockwiseFill = toGlyph 0XEB94
remixClockwiseLine = toGlyph 0XEB95
remixCloseCircleFill = toGlyph 0XEB96
remixCloseCircleLine = toGlyph 0XEB97
remixCloseFill = toGlyph 0XEB98
remixCloseLine = toGlyph 0XEB99
remixClosedCaptioningFill = toGlyph 0XEB9A
remixClosedCaptioningLine = toGlyph 0XEB9B
remixCloudFill = toGlyph 0XEB9C
remixCloudLine = toGlyph 0XEB9D
remixCloudOffFill = toGlyph 0XEB9E
remixCloudOffLine = toGlyph 0XEB9F
remixCloudWindyFill = toGlyph 0XEBA0
remixCloudWindyLine = toGlyph 0XEBA1
remixCloudy2Fill = toGlyph 0XEBA2
remixCloudy2Line = toGlyph 0XEBA3
remixCloudyFill = toGlyph 0XEBA4
remixCloudyLine = toGlyph 0XEBA5
remixCodeBoxFill = toGlyph 0XEBA6
remixCodeBoxLine = toGlyph 0XEBA7
remixCodeFill = toGlyph 0XEBA8
remixCodeLine = toGlyph 0XEBA9
remixCodeSFill = toGlyph 0XEBAA
remixCodeSLine = toGlyph 0XEBAB
remixCodeSSlashFill = toGlyph 0XEBAC
remixCodeSSlashLine = toGlyph 0XEBAD
remixCodeView = toGlyph 0XEBAE
remixCodepenFill = toGlyph 0XEBAF
remixCodepenLine = toGlyph 0XEBB0
remixCoinFill = toGlyph 0XEBB1
remixCoinLine = toGlyph 0XEBB2
remixCoinsFill = toGlyph 0XEBB3
remixCoinsLine = toGlyph 0XEBB4
remixCollageFill = toGlyph 0XEBB5
remixCollageLine = toGlyph 0XEBB6
remixCommandFill = toGlyph 0XEBB7
remixCommandLine = toGlyph 0XEBB8
remixCommunityFill = toGlyph 0XEBB9
remixCommunityLine = toGlyph 0XEBBA
remixCompass2Fill = toGlyph 0XEBBB
remixCompass2Line = toGlyph 0XEBBC
remixCompass3Fill = toGlyph 0XEBBD
remixCompass3Line = toGlyph 0XEBBE
remixCompass4Fill = toGlyph 0XEBBF
remixCompass4Line = toGlyph 0XEBC0
remixCompassDiscoverFill = toGlyph 0XEBC1
remixCompassDiscoverLine = toGlyph 0XEBC2
remixCompassFill = toGlyph 0XEBC3
remixCompassLine = toGlyph 0XEBC4
remixCompasses2Fill = toGlyph 0XEBC5
remixCompasses2Line = toGlyph 0XEBC6
remixCompassesFill = toGlyph 0XEBC7
remixCompassesLine = toGlyph 0XEBC8
remixComputerFill = toGlyph 0XEBC9
remixComputerLine = toGlyph 0XEBCA
remixContactsBook2Fill = toGlyph 0XEBCB
remixContactsBook2Line = toGlyph 0XEBCC
remixContactsBookFill = toGlyph 0XEBCD
remixContactsBookLine = toGlyph 0XEBCE
remixContactsBookUploadFill = toGlyph 0XEBCF
remixContactsBookUploadLine = toGlyph 0XEBD0
remixContactsFill = toGlyph 0XEBD1
remixContactsLine = toGlyph 0XEBD2
remixContrast2Fill = toGlyph 0XEBD3
remixContrast2Line = toGlyph 0XEBD4
remixContrastDrop2Fill = toGlyph 0XEBD5
remixContrastDrop2Line = toGlyph 0XEBD6
remixContrastDropFill = toGlyph 0XEBD7
remixContrastDropLine = toGlyph 0XEBD8
remixContrastFill = toGlyph 0XEBD9
remixContrastLine = toGlyph 0XEBDA
remixCopperCoinFill = toGlyph 0XEBDB
remixCopperCoinLine = toGlyph 0XEBDC
remixCopperDiamondFill = toGlyph 0XEBDD
remixCopperDiamondLine = toGlyph 0XEBDE
remixCopyleftFill = toGlyph 0XEBDF
remixCopyleftLine = toGlyph 0XEBE0
remixCopyrightFill = toGlyph 0XEBE1
remixCopyrightLine = toGlyph 0XEBE2
remixCoreosFill = toGlyph 0XEBE3
remixCoreosLine = toGlyph 0XEBE4
remixCoupon2Fill = toGlyph 0XEBE5
remixCoupon2Line = toGlyph 0XEBE6
remixCoupon3Fill = toGlyph 0XEBE7
remixCoupon3Line = toGlyph 0XEBE8
remixCoupon4Fill = toGlyph 0XEBE9
remixCoupon4Line = toGlyph 0XEBEA
remixCoupon5Fill = toGlyph 0XEBEB
remixCoupon5Line = toGlyph 0XEBEC
remixCouponFill = toGlyph 0XEBED
remixCouponLine = toGlyph 0XEBEE
remixCpuFill = toGlyph 0XEBEF
remixCpuLine = toGlyph 0XEBF0
remixCreativeCommonsByFill = toGlyph 0XEBF1
remixCreativeCommonsByLine = toGlyph 0XEBF2
remixCreativeCommonsFill = toGlyph 0XEBF3
remixCreativeCommonsLine = toGlyph 0XEBF4
remixCreativeCommonsNcFill = toGlyph 0XEBF5
remixCreativeCommonsNcLine = toGlyph 0XEBF6
remixCreativeCommonsNdFill = toGlyph 0XEBF7
remixCreativeCommonsNdLine = toGlyph 0XEBF8
remixCreativeCommonsSaFill = toGlyph 0XEBF9
remixCreativeCommonsSaLine = toGlyph 0XEBFA
remixCreativeCommonsZeroFill = toGlyph 0XEBFB
remixCreativeCommonsZeroLine = toGlyph 0XEBFC
remixCriminalFill = toGlyph 0XEBFD
remixCriminalLine = toGlyph 0XEBFE
remixCrop2Fill = toGlyph 0XEBFF
remixCrop2Line = toGlyph 0XEC00
remixCropFill = toGlyph 0XEC01
remixCropLine = toGlyph 0XEC02
remixCss3Fill = toGlyph 0XEC03
remixCss3Line = toGlyph 0XEC04
remixCupFill = toGlyph 0XEC05
remixCupLine = toGlyph 0XEC06
remixCurrencyFill = toGlyph 0XEC07
remixCurrencyLine = toGlyph 0XEC08
remixCursorFill = toGlyph 0XEC09
remixCursorLine = toGlyph 0XEC0A
remixCustomerService2Fill = toGlyph 0XEC0B
remixCustomerService2Line = toGlyph 0XEC0C
remixCustomerServiceFill = toGlyph 0XEC0D
remixCustomerServiceLine = toGlyph 0XEC0E
remixDashboard2Fill = toGlyph 0XEC0F
remixDashboard2Line = toGlyph 0XEC10
remixDashboard3Fill = toGlyph 0XEC11
remixDashboard3Line = toGlyph 0XEC12
remixDashboardFill = toGlyph 0XEC13
remixDashboardLine = toGlyph 0XEC14
remixDatabase2Fill = toGlyph 0XEC15
remixDatabase2Line = toGlyph 0XEC16
remixDatabaseFill = toGlyph 0XEC17
remixDatabaseLine = toGlyph 0XEC18
remixDeleteBack2Fill = toGlyph 0XEC19
remixDeleteBack2Line = toGlyph 0XEC1A
remixDeleteBackFill = toGlyph 0XEC1B
remixDeleteBackLine = toGlyph 0XEC1C
remixDeleteBin2Fill = toGlyph 0XEC1D
remixDeleteBin2Line = toGlyph 0XEC1E
remixDeleteBin3Fill = toGlyph 0XEC1F
remixDeleteBin3Line = toGlyph 0XEC20
remixDeleteBin4Fill = toGlyph 0XEC21
remixDeleteBin4Line = toGlyph 0XEC22
remixDeleteBin5Fill = toGlyph 0XEC23
remixDeleteBin5Line = toGlyph 0XEC24
remixDeleteBin6Fill = toGlyph 0XEC25
remixDeleteBin6Line = toGlyph 0XEC26
remixDeleteBin7Fill = toGlyph 0XEC27
remixDeleteBin7Line = toGlyph 0XEC28
remixDeleteBinFill = toGlyph 0XEC29
remixDeleteBinLine = toGlyph 0XEC2A
remixDeleteColumn = toGlyph 0XEC2B
remixDeleteRow = toGlyph 0XEC2C
remixDeviceFill = toGlyph 0XEC2D
remixDeviceLine = toGlyph 0XEC2E
remixDeviceRecoverFill = toGlyph 0XEC2F
remixDeviceRecoverLine = toGlyph 0XEC30
remixDingdingFill = toGlyph 0XEC31
remixDingdingLine = toGlyph 0XEC32
remixDirectionFill = toGlyph 0XEC33
remixDirectionLine = toGlyph 0XEC34
remixDiscFill = toGlyph 0XEC35
remixDiscLine = toGlyph 0XEC36
remixDiscordFill = toGlyph 0XEC37
remixDiscordLine = toGlyph 0XEC38
remixDiscussFill = toGlyph 0XEC39
remixDiscussLine = toGlyph 0XEC3A
remixDislikeFill = toGlyph 0XEC3B
remixDislikeLine = toGlyph 0XEC3C
remixDisqusFill = toGlyph 0XEC3D
remixDisqusLine = toGlyph 0XEC3E
remixDivideFill = toGlyph 0XEC3F
remixDivideLine = toGlyph 0XEC40
remixDonutChartFill = toGlyph 0XEC41
remixDonutChartLine = toGlyph 0XEC42
remixDoorClosedFill = toGlyph 0XEC43
remixDoorClosedLine = toGlyph 0XEC44
remixDoorFill = toGlyph 0XEC45
remixDoorLine = toGlyph 0XEC46
remixDoorLockBoxFill = toGlyph 0XEC47
remixDoorLockBoxLine = toGlyph 0XEC48
remixDoorLockFill = toGlyph 0XEC49
remixDoorLockLine = toGlyph 0XEC4A
remixDoorOpenFill = toGlyph 0XEC4B
remixDoorOpenLine = toGlyph 0XEC4C
remixDossierFill = toGlyph 0XEC4D
remixDossierLine = toGlyph 0XEC4E
remixDoubanFill = toGlyph 0XEC4F
remixDoubanLine = toGlyph 0XEC50
remixDoubleQuotesL = toGlyph 0XEC51
remixDoubleQuotesR = toGlyph 0XEC52
remixDownload2Fill = toGlyph 0XEC53
remixDownload2Line = toGlyph 0XEC54
remixDownloadCloud2Fill = toGlyph 0XEC55
remixDownloadCloud2Line = toGlyph 0XEC56
remixDownloadCloudFill = toGlyph 0XEC57
remixDownloadCloudLine = toGlyph 0XEC58
remixDownloadFill = toGlyph 0XEC59
remixDownloadLine = toGlyph 0XEC5A
remixDraftFill = toGlyph 0XEC5B
remixDraftLine = toGlyph 0XEC5C
remixDragDropFill = toGlyph 0XEC5D
remixDragDropLine = toGlyph 0XEC5E
remixDragMove2Fill = toGlyph 0XEC5F
remixDragMove2Line = toGlyph 0XEC60
remixDragMoveFill = toGlyph 0XEC61
remixDragMoveLine = toGlyph 0XEC62
remixDribbbleFill = toGlyph 0XEC63
remixDribbbleLine = toGlyph 0XEC64
remixDriveFill = toGlyph 0XEC65
remixDriveLine = toGlyph 0XEC66
remixDrizzleFill = toGlyph 0XEC67
remixDrizzleLine = toGlyph 0XEC68
remixDropFill = toGlyph 0XEC69
remixDropLine = toGlyph 0XEC6A
remixDropboxFill = toGlyph 0XEC6B
remixDropboxLine = toGlyph 0XEC6C
remixDualSim1Fill = toGlyph 0XEC6D
remixDualSim1Line = toGlyph 0XEC6E
remixDualSim2Fill = toGlyph 0XEC6F
remixDualSim2Line = toGlyph 0XEC70
remixDvFill = toGlyph 0XEC71
remixDvLine = toGlyph 0XEC72
remixDvdFill = toGlyph 0XEC73
remixDvdLine = toGlyph 0XEC74
remixEBike2Fill = toGlyph 0XEC75
remixEBike2Line = toGlyph 0XEC76
remixEBikeFill = toGlyph 0XEC77
remixEBikeLine = toGlyph 0XEC78
remixEarthFill = toGlyph 0XEC79
remixEarthLine = toGlyph 0XEC7A
remixEarthquakeFill = toGlyph 0XEC7B
remixEarthquakeLine = toGlyph 0XEC7C
remixEdgeFill = toGlyph 0XEC7D
remixEdgeLine = toGlyph 0XEC7E
remixEdit2Fill = toGlyph 0XEC7F
remixEdit2Line = toGlyph 0XEC80
remixEditBoxFill = toGlyph 0XEC81
remixEditBoxLine = toGlyph 0XEC82
remixEditCircleFill = toGlyph 0XEC83
remixEditCircleLine = toGlyph 0XEC84
remixEditFill = toGlyph 0XEC85
remixEditLine = toGlyph 0XEC86
remixEjectFill = toGlyph 0XEC87
remixEjectLine = toGlyph 0XEC88
remixEmotion2Fill = toGlyph 0XEC89
remixEmotion2Line = toGlyph 0XEC8A
remixEmotionFill = toGlyph 0XEC8B
remixEmotionHappyFill = toGlyph 0XEC8C
remixEmotionHappyLine = toGlyph 0XEC8D
remixEmotionLaughFill = toGlyph 0XEC8E
remixEmotionLaughLine = toGlyph 0XEC8F
remixEmotionLine = toGlyph 0XEC90
remixEmotionNormalFill = toGlyph 0XEC91
remixEmotionNormalLine = toGlyph 0XEC92
remixEmotionSadFill = toGlyph 0XEC93
remixEmotionSadLine = toGlyph 0XEC94
remixEmotionUnhappyFill = toGlyph 0XEC95
remixEmotionUnhappyLine = toGlyph 0XEC96
remixEmpathizeFill = toGlyph 0XEC97
remixEmpathizeLine = toGlyph 0XEC98
remixEmphasisCn = toGlyph 0XEC99
remixEmphasis = toGlyph 0XEC9A
remixEnglishInput = toGlyph 0XEC9B
remixEqualizerFill = toGlyph 0XEC9C
remixEqualizerLine = toGlyph 0XEC9D
remixEraserFill = toGlyph 0XEC9E
remixEraserLine = toGlyph 0XEC9F
remixErrorWarningFill = toGlyph 0XECA0
remixErrorWarningLine = toGlyph 0XECA1
remixEvernoteFill = toGlyph 0XECA2
remixEvernoteLine = toGlyph 0XECA3
remixExchangeBoxFill = toGlyph 0XECA4
remixExchangeBoxLine = toGlyph 0XECA5
remixExchangeCnyFill = toGlyph 0XECA6
remixExchangeCnyLine = toGlyph 0XECA7
remixExchangeDollarFill = toGlyph 0XECA8
remixExchangeDollarLine = toGlyph 0XECA9
remixExchangeFill = toGlyph 0XECAA
remixExchangeFundsFill = toGlyph 0XECAB
remixExchangeFundsLine = toGlyph 0XECAC
remixExchangeLine = toGlyph 0XECAD
remixExternalLinkFill = toGlyph 0XECAE
remixExternalLinkLine = toGlyph 0XECAF
remixEye2Fill = toGlyph 0XECB0
remixEye2Line = toGlyph 0XECB1
remixEyeCloseFill = toGlyph 0XECB2
remixEyeCloseLine = toGlyph 0XECB3
remixEyeFill = toGlyph 0XECB4
remixEyeLine = toGlyph 0XECB5
remixEyeOffFill = toGlyph 0XECB6
remixEyeOffLine = toGlyph 0XECB7
remixFacebookBoxFill = toGlyph 0XECB8
remixFacebookBoxLine = toGlyph 0XECB9
remixFacebookCircleFill = toGlyph 0XECBA
remixFacebookCircleLine = toGlyph 0XECBB
remixFacebookFill = toGlyph 0XECBC
remixFacebookLine = toGlyph 0XECBD
remixFahrenheitFill = toGlyph 0XECBE
remixFahrenheitLine = toGlyph 0XECBF
remixFeedbackFill = toGlyph 0XECC0
remixFeedbackLine = toGlyph 0XECC1
remixFile2Fill = toGlyph 0XECC2
remixFile2Line = toGlyph 0XECC3
remixFile3Fill = toGlyph 0XECC4
remixFile3Line = toGlyph 0XECC5
remixFile4Fill = toGlyph 0XECC6
remixFile4Line = toGlyph 0XECC7
remixFileAddFill = toGlyph 0XECC8
remixFileAddLine = toGlyph 0XECC9
remixFileChart2Fill = toGlyph 0XECCA
remixFileChart2Line = toGlyph 0XECCB
remixFileChartFill = toGlyph 0XECCC
remixFileChartLine = toGlyph 0XECCD
remixFileCloudFill = toGlyph 0XECCE
remixFileCloudLine = toGlyph 0XECCF
remixFileCodeFill = toGlyph 0XECD0
remixFileCodeLine = toGlyph 0XECD1
remixFileCopy2Fill = toGlyph 0XECD2
remixFileCopy2Line = toGlyph 0XECD3
remixFileCopyFill = toGlyph 0XECD4
remixFileCopyLine = toGlyph 0XECD5
remixFileDamageFill = toGlyph 0XECD6
remixFileDamageLine = toGlyph 0XECD7
remixFileDownloadFill = toGlyph 0XECD8
remixFileDownloadLine = toGlyph 0XECD9
remixFileEditFill = toGlyph 0XECDA
remixFileEditLine = toGlyph 0XECDB
remixFileExcel2Fill = toGlyph 0XECDC
remixFileExcel2Line = toGlyph 0XECDD
remixFileExcelFill = toGlyph 0XECDE
remixFileExcelLine = toGlyph 0XECDF
remixFileFill = toGlyph 0XECE0
remixFileForbidFill = toGlyph 0XECE1
remixFileForbidLine = toGlyph 0XECE2
remixFileGifFill = toGlyph 0XECE3
remixFileGifLine = toGlyph 0XECE4
remixFileHistoryFill = toGlyph 0XECE5
remixFileHistoryLine = toGlyph 0XECE6
remixFileHwpFill = toGlyph 0XECE7
remixFileHwpLine = toGlyph 0XECE8
remixFileInfoFill = toGlyph 0XECE9
remixFileInfoLine = toGlyph 0XECEA
remixFileLine = toGlyph 0XECEB
remixFileList2Fill = toGlyph 0XECEC
remixFileList2Line = toGlyph 0XECED
remixFileList3Fill = toGlyph 0XECEE
remixFileList3Line = toGlyph 0XECEF
remixFileListFill = toGlyph 0XECF0
remixFileListLine = toGlyph 0XECF1
remixFileLockFill = toGlyph 0XECF2
remixFileLockLine = toGlyph 0XECF3
remixFileMarkFill = toGlyph 0XECF4
remixFileMarkLine = toGlyph 0XECF5
remixFileMusicFill = toGlyph 0XECF6
remixFileMusicLine = toGlyph 0XECF7
remixFilePaper2Fill = toGlyph 0XECF8
remixFilePaper2Line = toGlyph 0XECF9
remixFilePaperFill = toGlyph 0XECFA
remixFilePaperLine = toGlyph 0XECFB
remixFilePdfFill = toGlyph 0XECFC
remixFilePdfLine = toGlyph 0XECFD
remixFilePpt2Fill = toGlyph 0XECFE
remixFilePpt2Line = toGlyph 0XECFF
remixFilePptFill = toGlyph 0XED00
remixFilePptLine = toGlyph 0XED01
remixFileReduceFill = toGlyph 0XED02
remixFileReduceLine = toGlyph 0XED03
remixFileSearchFill = toGlyph 0XED04
remixFileSearchLine = toGlyph 0XED05
remixFileSettingsFill = toGlyph 0XED06
remixFileSettingsLine = toGlyph 0XED07
remixFileShield2Fill = toGlyph 0XED08
remixFileShield2Line = toGlyph 0XED09
remixFileShieldFill = toGlyph 0XED0A
remixFileShieldLine = toGlyph 0XED0B
remixFileShredFill = toGlyph 0XED0C
remixFileShredLine = toGlyph 0XED0D
remixFileTextFill = toGlyph 0XED0E
remixFileTextLine = toGlyph 0XED0F
remixFileTransferFill = toGlyph 0XED10
remixFileTransferLine = toGlyph 0XED11
remixFileUnknowFill = toGlyph 0XED12
remixFileUnknowLine = toGlyph 0XED13
remixFileUploadFill = toGlyph 0XED14
remixFileUploadLine = toGlyph 0XED15
remixFileUserFill = toGlyph 0XED16
remixFileUserLine = toGlyph 0XED17
remixFileWarningFill = toGlyph 0XED18
remixFileWarningLine = toGlyph 0XED19
remixFileWord2Fill = toGlyph 0XED1A
remixFileWord2Line = toGlyph 0XED1B
remixFileWordFill = toGlyph 0XED1C
remixFileWordLine = toGlyph 0XED1D
remixFileZipFill = toGlyph 0XED1E
remixFileZipLine = toGlyph 0XED1F
remixFilmFill = toGlyph 0XED20
remixFilmLine = toGlyph 0XED21
remixFilter2Fill = toGlyph 0XED22
remixFilter2Line = toGlyph 0XED23
remixFilter3Fill = toGlyph 0XED24
remixFilter3Line = toGlyph 0XED25
remixFilterFill = toGlyph 0XED26
remixFilterLine = toGlyph 0XED27
remixFilterOffFill = toGlyph 0XED28
remixFilterOffLine = toGlyph 0XED29
remixFindReplaceFill = toGlyph 0XED2A
remixFindReplaceLine = toGlyph 0XED2B
remixFinderFill = toGlyph 0XED2C
remixFinderLine = toGlyph 0XED2D
remixFingerprint2Fill = toGlyph 0XED2E
remixFingerprint2Line = toGlyph 0XED2F
remixFingerprintFill = toGlyph 0XED30
remixFingerprintLine = toGlyph 0XED31
remixFireFill = toGlyph 0XED32
remixFireLine = toGlyph 0XED33
remixFirefoxFill = toGlyph 0XED34
remixFirefoxLine = toGlyph 0XED35
remixFirstAidKitFill = toGlyph 0XED36
remixFirstAidKitLine = toGlyph 0XED37
remixFlag2Fill = toGlyph 0XED38
remixFlag2Line = toGlyph 0XED39
remixFlagFill = toGlyph 0XED3A
remixFlagLine = toGlyph 0XED3B
remixFlashlightFill = toGlyph 0XED3C
remixFlashlightLine = toGlyph 0XED3D
remixFlaskFill = toGlyph 0XED3E
remixFlaskLine = toGlyph 0XED3F
remixFlightLandFill = toGlyph 0XED40
remixFlightLandLine = toGlyph 0XED41
remixFlightTakeoffFill = toGlyph 0XED42
remixFlightTakeoffLine = toGlyph 0XED43
remixFloodFill = toGlyph 0XED44
remixFloodLine = toGlyph 0XED45
remixFlowChart = toGlyph 0XED46
remixFlutterFill = toGlyph 0XED47
remixFlutterLine = toGlyph 0XED48
remixFocus2Fill = toGlyph 0XED49
remixFocus2Line = toGlyph 0XED4A
remixFocus3Fill = toGlyph 0XED4B
remixFocus3Line = toGlyph 0XED4C
remixFocusFill = toGlyph 0XED4D
remixFocusLine = toGlyph 0XED4E
remixFoggyFill = toGlyph 0XED4F
remixFoggyLine = toGlyph 0XED50
remixFolder2Fill = toGlyph 0XED51
remixFolder2Line = toGlyph 0XED52
remixFolder3Fill = toGlyph 0XED53
remixFolder3Line = toGlyph 0XED54
remixFolder4Fill = toGlyph 0XED55
remixFolder4Line = toGlyph 0XED56
remixFolder5Fill = toGlyph 0XED57
remixFolder5Line = toGlyph 0XED58
remixFolderAddFill = toGlyph 0XED59
remixFolderAddLine = toGlyph 0XED5A
remixFolderChart2Fill = toGlyph 0XED5B
remixFolderChart2Line = toGlyph 0XED5C
remixFolderChartFill = toGlyph 0XED5D
remixFolderChartLine = toGlyph 0XED5E
remixFolderDownloadFill = toGlyph 0XED5F
remixFolderDownloadLine = toGlyph 0XED60
remixFolderFill = toGlyph 0XED61
remixFolderForbidFill = toGlyph 0XED62
remixFolderForbidLine = toGlyph 0XED63
remixFolderHistoryFill = toGlyph 0XED64
remixFolderHistoryLine = toGlyph 0XED65
remixFolderInfoFill = toGlyph 0XED66
remixFolderInfoLine = toGlyph 0XED67
remixFolderKeyholeFill = toGlyph 0XED68
remixFolderKeyholeLine = toGlyph 0XED69
remixFolderLine = toGlyph 0XED6A
remixFolderLockFill = toGlyph 0XED6B
remixFolderLockLine = toGlyph 0XED6C
remixFolderMusicFill = toGlyph 0XED6D
remixFolderMusicLine = toGlyph 0XED6E
remixFolderOpenFill = toGlyph 0XED6F
remixFolderOpenLine = toGlyph 0XED70
remixFolderReceivedFill = toGlyph 0XED71
remixFolderReceivedLine = toGlyph 0XED72
remixFolderReduceFill = toGlyph 0XED73
remixFolderReduceLine = toGlyph 0XED74
remixFolderSettingsFill = toGlyph 0XED75
remixFolderSettingsLine = toGlyph 0XED76
remixFolderSharedFill = toGlyph 0XED77
remixFolderSharedLine = toGlyph 0XED78
remixFolderShield2Fill = toGlyph 0XED79
remixFolderShield2Line = toGlyph 0XED7A
remixFolderShieldFill = toGlyph 0XED7B
remixFolderShieldLine = toGlyph 0XED7C
remixFolderTransferFill = toGlyph 0XED7D
remixFolderTransferLine = toGlyph 0XED7E
remixFolderUnknowFill = toGlyph 0XED7F
remixFolderUnknowLine = toGlyph 0XED80
remixFolderUploadFill = toGlyph 0XED81
remixFolderUploadLine = toGlyph 0XED82
remixFolderUserFill = toGlyph 0XED83
remixFolderUserLine = toGlyph 0XED84
remixFolderWarningFill = toGlyph 0XED85
remixFolderWarningLine = toGlyph 0XED86
remixFolderZipFill = toGlyph 0XED87
remixFolderZipLine = toGlyph 0XED88
remixFoldersFill = toGlyph 0XED89
remixFoldersLine = toGlyph 0XED8A
remixFontColor = toGlyph 0XED8B
remixFontSize2 = toGlyph 0XED8C
remixFontSize = toGlyph 0XED8D
remixFootballFill = toGlyph 0XED8E
remixFootballLine = toGlyph 0XED8F
remixFootprintFill = toGlyph 0XED90
remixFootprintLine = toGlyph 0XED91
remixForbid2Fill = toGlyph 0XED92
remixForbid2Line = toGlyph 0XED93
remixForbidFill = toGlyph 0XED94
remixForbidLine = toGlyph 0XED95
remixFormatClear = toGlyph 0XED96
remixFridgeFill = toGlyph 0XED97
remixFridgeLine = toGlyph 0XED98
remixFullscreenExitFill = toGlyph 0XED99
remixFullscreenExitLine = toGlyph 0XED9A
remixFullscreenFill = toGlyph 0XED9B
remixFullscreenLine = toGlyph 0XED9C
remixFunctionFill = toGlyph 0XED9D
remixFunctionLine = toGlyph 0XED9E
remixFunctions = toGlyph 0XED9F
remixFundsBoxFill = toGlyph 0XEDA0
remixFundsBoxLine = toGlyph 0XEDA1
remixFundsFill = toGlyph 0XEDA2
remixFundsLine = toGlyph 0XEDA3
remixGalleryFill = toGlyph 0XEDA4
remixGalleryLine = toGlyph 0XEDA5
remixGalleryUploadFill = toGlyph 0XEDA6
remixGalleryUploadLine = toGlyph 0XEDA7
remixGameFill = toGlyph 0XEDA8
remixGameLine = toGlyph 0XEDA9
remixGamepadFill = toGlyph 0XEDAA
remixGamepadLine = toGlyph 0XEDAB
remixGasStationFill = toGlyph 0XEDAC
remixGasStationLine = toGlyph 0XEDAD
remixGatsbyFill = toGlyph 0XEDAE
remixGatsbyLine = toGlyph 0XEDAF
remixGenderlessFill = toGlyph 0XEDB0
remixGenderlessLine = toGlyph 0XEDB1
remixGhost2Fill = toGlyph 0XEDB2
remixGhost2Line = toGlyph 0XEDB3
remixGhostFill = toGlyph 0XEDB4
remixGhostLine = toGlyph 0XEDB5
remixGhostSmileFill = toGlyph 0XEDB6
remixGhostSmileLine = toGlyph 0XEDB7
remixGift2Fill = toGlyph 0XEDB8
remixGift2Line = toGlyph 0XEDB9
remixGiftFill = toGlyph 0XEDBA
remixGiftLine = toGlyph 0XEDBB
remixGitBranchFill = toGlyph 0XEDBC
remixGitBranchLine = toGlyph 0XEDBD
remixGitCommitFill = toGlyph 0XEDBE
remixGitCommitLine = toGlyph 0XEDBF
remixGitMergeFill = toGlyph 0XEDC0
remixGitMergeLine = toGlyph 0XEDC1
remixGitPullRequestFill = toGlyph 0XEDC2
remixGitPullRequestLine = toGlyph 0XEDC3
remixGitRepositoryCommitsFill = toGlyph 0XEDC4
remixGitRepositoryCommitsLine = toGlyph 0XEDC5
remixGitRepositoryFill = toGlyph 0XEDC6
remixGitRepositoryLine = toGlyph 0XEDC7
remixGitRepositoryPrivateFill = toGlyph 0XEDC8
remixGitRepositoryPrivateLine = toGlyph 0XEDC9
remixGithubFill = toGlyph 0XEDCA
remixGithubLine = toGlyph 0XEDCB
remixGitlabFill = toGlyph 0XEDCC
remixGitlabLine = toGlyph 0XEDCD
remixGlobalFill = toGlyph 0XEDCE
remixGlobalLine = toGlyph 0XEDCF
remixGlobeFill = toGlyph 0XEDD0
remixGlobeLine = toGlyph 0XEDD1
remixGobletFill = toGlyph 0XEDD2
remixGobletLine = toGlyph 0XEDD3
remixGoogleFill = toGlyph 0XEDD4
remixGoogleLine = toGlyph 0XEDD5
remixGooglePlayFill = toGlyph 0XEDD6
remixGooglePlayLine = toGlyph 0XEDD7
remixGovernmentFill = toGlyph 0XEDD8
remixGovernmentLine = toGlyph 0XEDD9
remixGpsFill = toGlyph 0XEDDA
remixGpsLine = toGlyph 0XEDDB
remixGradienterFill = toGlyph 0XEDDC
remixGradienterLine = toGlyph 0XEDDD
remixGridFill = toGlyph 0XEDDE
remixGridLine = toGlyph 0XEDDF
remixGroup2Fill = toGlyph 0XEDE0
remixGroup2Line = toGlyph 0XEDE1
remixGroupFill = toGlyph 0XEDE2
remixGroupLine = toGlyph 0XEDE3
remixGuideFill = toGlyph 0XEDE4
remixGuideLine = toGlyph 0XEDE5
remixH1 = toGlyph 0XEDE6
remixH2 = toGlyph 0XEDE7
remixH3 = toGlyph 0XEDE8
remixH4 = toGlyph 0XEDE9
remixH5 = toGlyph 0XEDEA
remixH6 = toGlyph 0XEDEB
remixHailFill = toGlyph 0XEDEC
remixHailLine = toGlyph 0XEDED
remixHammerFill = toGlyph 0XEDEE
remixHammerLine = toGlyph 0XEDEF
remixHandCoinFill = toGlyph 0XEDF0
remixHandCoinLine = toGlyph 0XEDF1
remixHandHeartFill = toGlyph 0XEDF2
remixHandHeartLine = toGlyph 0XEDF3
remixHandSanitizerFill = toGlyph 0XEDF4
remixHandSanitizerLine = toGlyph 0XEDF5
remixHandbagFill = toGlyph 0XEDF6
remixHandbagLine = toGlyph 0XEDF7
remixHardDrive2Fill = toGlyph 0XEDF8
remixHardDrive2Line = toGlyph 0XEDF9
remixHardDriveFill = toGlyph 0XEDFA
remixHardDriveLine = toGlyph 0XEDFB
remixHashtag = toGlyph 0XEDFC
remixHaze2Fill = toGlyph 0XEDFD
remixHaze2Line = toGlyph 0XEDFE
remixHazeFill = toGlyph 0XEDFF
remixHazeLine = toGlyph 0XEE00
remixHdFill = toGlyph 0XEE01
remixHdLine = toGlyph 0XEE02
remixHeading = toGlyph 0XEE03
remixHeadphoneFill = toGlyph 0XEE04
remixHeadphoneLine = toGlyph 0XEE05
remixHealthBookFill = toGlyph 0XEE06
remixHealthBookLine = toGlyph 0XEE07
remixHeart2Fill = toGlyph 0XEE08
remixHeart2Line = toGlyph 0XEE09
remixHeart3Fill = toGlyph 0XEE0A
remixHeart3Line = toGlyph 0XEE0B
remixHeartAddFill = toGlyph 0XEE0C
remixHeartAddLine = toGlyph 0XEE0D
remixHeartFill = toGlyph 0XEE0E
remixHeartLine = toGlyph 0XEE0F
remixHeartPulseFill = toGlyph 0XEE10
remixHeartPulseLine = toGlyph 0XEE11
remixHeartsFill = toGlyph 0XEE12
remixHeartsLine = toGlyph 0XEE13
remixHeavyShowersFill = toGlyph 0XEE14
remixHeavyShowersLine = toGlyph 0XEE15
remixHistoryFill = toGlyph 0XEE16
remixHistoryLine = toGlyph 0XEE17
remixHome2Fill = toGlyph 0XEE18
remixHome2Line = toGlyph 0XEE19
remixHome3Fill = toGlyph 0XEE1A
remixHome3Line = toGlyph 0XEE1B
remixHome4Fill = toGlyph 0XEE1C
remixHome4Line = toGlyph 0XEE1D
remixHome5Fill = toGlyph 0XEE1E
remixHome5Line = toGlyph 0XEE1F
remixHome6Fill = toGlyph 0XEE20
remixHome6Line = toGlyph 0XEE21
remixHome7Fill = toGlyph 0XEE22
remixHome7Line = toGlyph 0XEE23
remixHome8Fill = toGlyph 0XEE24
remixHome8Line = toGlyph 0XEE25
remixHomeFill = toGlyph 0XEE26
remixHomeGearFill = toGlyph 0XEE27
remixHomeGearLine = toGlyph 0XEE28
remixHomeHeartFill = toGlyph 0XEE29
remixHomeHeartLine = toGlyph 0XEE2A
remixHomeLine = toGlyph 0XEE2B
remixHomeSmile2Fill = toGlyph 0XEE2C
remixHomeSmile2Line = toGlyph 0XEE2D
remixHomeSmileFill = toGlyph 0XEE2E
remixHomeSmileLine = toGlyph 0XEE2F
remixHomeWifiFill = toGlyph 0XEE30
remixHomeWifiLine = toGlyph 0XEE31
remixHonorOfKingsFill = toGlyph 0XEE32
remixHonorOfKingsLine = toGlyph 0XEE33
remixHonourFill = toGlyph 0XEE34
remixHonourLine = toGlyph 0XEE35
remixHospitalFill = toGlyph 0XEE36
remixHospitalLine = toGlyph 0XEE37
remixHotelBedFill = toGlyph 0XEE38
remixHotelBedLine = toGlyph 0XEE39
remixHotelFill = toGlyph 0XEE3A
remixHotelLine = toGlyph 0XEE3B
remixHotspotFill = toGlyph 0XEE3C
remixHotspotLine = toGlyph 0XEE3D
remixHqFill = toGlyph 0XEE3E
remixHqLine = toGlyph 0XEE3F
remixHtml5Fill = toGlyph 0XEE40
remixHtml5Line = toGlyph 0XEE41
remixIeFill = toGlyph 0XEE42
remixIeLine = toGlyph 0XEE43
remixImage2Fill = toGlyph 0XEE44
remixImage2Line = toGlyph 0XEE45
remixImageAddFill = toGlyph 0XEE46
remixImageAddLine = toGlyph 0XEE47
remixImageEditFill = toGlyph 0XEE48
remixImageEditLine = toGlyph 0XEE49
remixImageFill = toGlyph 0XEE4A
remixImageLine = toGlyph 0XEE4B
remixInboxArchiveFill = toGlyph 0XEE4C
remixInboxArchiveLine = toGlyph 0XEE4D
remixInboxFill = toGlyph 0XEE4E
remixInboxLine = toGlyph 0XEE4F
remixInboxUnarchiveFill = toGlyph 0XEE50
remixInboxUnarchiveLine = toGlyph 0XEE51
remixIncreaseDecreaseFill = toGlyph 0XEE52
remixIncreaseDecreaseLine = toGlyph 0XEE53
remixIndentDecrease = toGlyph 0XEE54
remixIndentIncrease = toGlyph 0XEE55
remixIndeterminateCircleFill = toGlyph 0XEE56
remixIndeterminateCircleLine = toGlyph 0XEE57
remixInformationFill = toGlyph 0XEE58
remixInformationLine = toGlyph 0XEE59
remixInfraredThermometerFill = toGlyph 0XEE5A
remixInfraredThermometerLine = toGlyph 0XEE5B
remixInkBottleFill = toGlyph 0XEE5C
remixInkBottleLine = toGlyph 0XEE5D
remixInputCursorMove = toGlyph 0XEE5E
remixInputMethodFill = toGlyph 0XEE5F
remixInputMethodLine = toGlyph 0XEE60
remixInsertColumnLeft = toGlyph 0XEE61
remixInsertColumnRight = toGlyph 0XEE62
remixInsertRowBottom = toGlyph 0XEE63
remixInsertRowTop = toGlyph 0XEE64
remixInstagramFill = toGlyph 0XEE65
remixInstagramLine = toGlyph 0XEE66
remixInstallFill = toGlyph 0XEE67
remixInstallLine = toGlyph 0XEE68
remixInvisionFill = toGlyph 0XEE69
remixInvisionLine = toGlyph 0XEE6A
remixItalic = toGlyph 0XEE6B
remixKakaoTalkFill = toGlyph 0XEE6C
remixKakaoTalkLine = toGlyph 0XEE6D
remixKey2Fill = toGlyph 0XEE6E
remixKey2Line = toGlyph 0XEE6F
remixKeyFill = toGlyph 0XEE70
remixKeyLine = toGlyph 0XEE71
remixKeyboardBoxFill = toGlyph 0XEE72
remixKeyboardBoxLine = toGlyph 0XEE73
remixKeyboardFill = toGlyph 0XEE74
remixKeyboardLine = toGlyph 0XEE75
remixKeynoteFill = toGlyph 0XEE76
remixKeynoteLine = toGlyph 0XEE77
remixKnifeBloodFill = toGlyph 0XEE78
remixKnifeBloodLine = toGlyph 0XEE79
remixKnifeFill = toGlyph 0XEE7A
remixKnifeLine = toGlyph 0XEE7B
remixLandscapeFill = toGlyph 0XEE7C
remixLandscapeLine = toGlyph 0XEE7D
remixLayout2Fill = toGlyph 0XEE7E
remixLayout2Line = toGlyph 0XEE7F
remixLayout3Fill = toGlyph 0XEE80
remixLayout3Line = toGlyph 0XEE81
remixLayout4Fill = toGlyph 0XEE82
remixLayout4Line = toGlyph 0XEE83
remixLayout5Fill = toGlyph 0XEE84
remixLayout5Line = toGlyph 0XEE85
remixLayout6Fill = toGlyph 0XEE86
remixLayout6Line = toGlyph 0XEE87
remixLayoutBottom2Fill = toGlyph 0XEE88
remixLayoutBottom2Line = toGlyph 0XEE89
remixLayoutBottomFill = toGlyph 0XEE8A
remixLayoutBottomLine = toGlyph 0XEE8B
remixLayoutColumnFill = toGlyph 0XEE8C
remixLayoutColumnLine = toGlyph 0XEE8D
remixLayoutFill = toGlyph 0XEE8E
remixLayoutGridFill = toGlyph 0XEE8F
remixLayoutGridLine = toGlyph 0XEE90
remixLayoutLeft2Fill = toGlyph 0XEE91
remixLayoutLeft2Line = toGlyph 0XEE92
remixLayoutLeftFill = toGlyph 0XEE93
remixLayoutLeftLine = toGlyph 0XEE94
remixLayoutLine = toGlyph 0XEE95
remixLayoutMasonryFill = toGlyph 0XEE96
remixLayoutMasonryLine = toGlyph 0XEE97
remixLayoutRight2Fill = toGlyph 0XEE98
remixLayoutRight2Line = toGlyph 0XEE99
remixLayoutRightFill = toGlyph 0XEE9A
remixLayoutRightLine = toGlyph 0XEE9B
remixLayoutRowFill = toGlyph 0XEE9C
remixLayoutRowLine = toGlyph 0XEE9D
remixLayoutTop2Fill = toGlyph 0XEE9E
remixLayoutTop2Line = toGlyph 0XEE9F
remixLayoutTopFill = toGlyph 0XEEA0
remixLayoutTopLine = toGlyph 0XEEA1
remixLeafFill = toGlyph 0XEEA2
remixLeafLine = toGlyph 0XEEA3
remixLifebuoyFill = toGlyph 0XEEA4
remixLifebuoyLine = toGlyph 0XEEA5
remixLightbulbFill = toGlyph 0XEEA6
remixLightbulbFlashFill = toGlyph 0XEEA7
remixLightbulbFlashLine = toGlyph 0XEEA8
remixLightbulbLine = toGlyph 0XEEA9
remixLineChartFill = toGlyph 0XEEAA
remixLineChartLine = toGlyph 0XEEAB
remixLineFill = toGlyph 0XEEAC
remixLineHeight = toGlyph 0XEEAD
remixLineLine = toGlyph 0XEEAE
remixLinkM = toGlyph 0XEEAF
remixLinkUnlinkM = toGlyph 0XEEB0
remixLinkUnlink = toGlyph 0XEEB1
remixLink = toGlyph 0XEEB2
remixLinkedinBoxFill = toGlyph 0XEEB3
remixLinkedinBoxLine = toGlyph 0XEEB4
remixLinkedinFill = toGlyph 0XEEB5
remixLinkedinLine = toGlyph 0XEEB6
remixLinksFill = toGlyph 0XEEB7
remixLinksLine = toGlyph 0XEEB8
remixListCheck2 = toGlyph 0XEEB9
remixListCheck = toGlyph 0XEEBA
remixListOrdered = toGlyph 0XEEBB
remixListSettingsFill = toGlyph 0XEEBC
remixListSettingsLine = toGlyph 0XEEBD
remixListUnordered = toGlyph 0XEEBE
remixLiveFill = toGlyph 0XEEBF
remixLiveLine = toGlyph 0XEEC0
remixLoader2Fill = toGlyph 0XEEC1
remixLoader2Line = toGlyph 0XEEC2
remixLoader3Fill = toGlyph 0XEEC3
remixLoader3Line = toGlyph 0XEEC4
remixLoader4Fill = toGlyph 0XEEC5
remixLoader4Line = toGlyph 0XEEC6
remixLoader5Fill = toGlyph 0XEEC7
remixLoader5Line = toGlyph 0XEEC8
remixLoaderFill = toGlyph 0XEEC9
remixLoaderLine = toGlyph 0XEECA
remixLock2Fill = toGlyph 0XEECB
remixLock2Line = toGlyph 0XEECC
remixLockFill = toGlyph 0XEECD
remixLockLine = toGlyph 0XEECE
remixLockPasswordFill = toGlyph 0XEECF
remixLockPasswordLine = toGlyph 0XEED0
remixLockUnlockFill = toGlyph 0XEED1
remixLockUnlockLine = toGlyph 0XEED2
remixLoginBoxFill = toGlyph 0XEED3
remixLoginBoxLine = toGlyph 0XEED4
remixLoginCircleFill = toGlyph 0XEED5
remixLoginCircleLine = toGlyph 0XEED6
remixLogoutBoxFill = toGlyph 0XEED7
remixLogoutBoxLine = toGlyph 0XEED8
remixLogoutBoxRFill = toGlyph 0XEED9
remixLogoutBoxRLine = toGlyph 0XEEDA
remixLogoutCircleFill = toGlyph 0XEEDB
remixLogoutCircleLine = toGlyph 0XEEDC
remixLogoutCircleRFill = toGlyph 0XEEDD
remixLogoutCircleRLine = toGlyph 0XEEDE
remixLuggageCartFill = toGlyph 0XEEDF
remixLuggageCartLine = toGlyph 0XEEE0
remixLuggageDepositFill = toGlyph 0XEEE1
remixLuggageDepositLine = toGlyph 0XEEE2
remixLungsFill = toGlyph 0XEEE3
remixLungsLine = toGlyph 0XEEE4
remixMacFill = toGlyph 0XEEE5
remixMacLine = toGlyph 0XEEE6
remixMacbookFill = toGlyph 0XEEE7
remixMacbookLine = toGlyph 0XEEE8
remixMagicFill = toGlyph 0XEEE9
remixMagicLine = toGlyph 0XEEEA
remixMailAddFill = toGlyph 0XEEEB
remixMailAddLine = toGlyph 0XEEEC
remixMailCheckFill = toGlyph 0XEEED
remixMailCheckLine = toGlyph 0XEEEE
remixMailCloseFill = toGlyph 0XEEEF
remixMailCloseLine = toGlyph 0XEEF0
remixMailDownloadFill = toGlyph 0XEEF1
remixMailDownloadLine = toGlyph 0XEEF2
remixMailFill = toGlyph 0XEEF3
remixMailForbidFill = toGlyph 0XEEF4
remixMailForbidLine = toGlyph 0XEEF5
remixMailLine = toGlyph 0XEEF6
remixMailLockFill = toGlyph 0XEEF7
remixMailLockLine = toGlyph 0XEEF8
remixMailOpenFill = toGlyph 0XEEF9
remixMailOpenLine = toGlyph 0XEEFA
remixMailSendFill = toGlyph 0XEEFB
remixMailSendLine = toGlyph 0XEEFC
remixMailSettingsFill = toGlyph 0XEEFD
remixMailSettingsLine = toGlyph 0XEEFE
remixMailStarFill = toGlyph 0XEEFF
remixMailStarLine = toGlyph 0XEF00
remixMailUnreadFill = toGlyph 0XEF01
remixMailUnreadLine = toGlyph 0XEF02
remixMailVolumeFill = toGlyph 0XEF03
remixMailVolumeLine = toGlyph 0XEF04
remixMap2Fill = toGlyph 0XEF05
remixMap2Line = toGlyph 0XEF06
remixMapFill = toGlyph 0XEF07
remixMapLine = toGlyph 0XEF08
remixMapPin2Fill = toGlyph 0XEF09
remixMapPin2Line = toGlyph 0XEF0A
remixMapPin3Fill = toGlyph 0XEF0B
remixMapPin3Line = toGlyph 0XEF0C
remixMapPin4Fill = toGlyph 0XEF0D
remixMapPin4Line = toGlyph 0XEF0E
remixMapPin5Fill = toGlyph 0XEF0F
remixMapPin5Line = toGlyph 0XEF10
remixMapPinAddFill = toGlyph 0XEF11
remixMapPinAddLine = toGlyph 0XEF12
remixMapPinFill = toGlyph 0XEF13
remixMapPinLine = toGlyph 0XEF14
remixMapPinRangeFill = toGlyph 0XEF15
remixMapPinRangeLine = toGlyph 0XEF16
remixMapPinTimeFill = toGlyph 0XEF17
remixMapPinTimeLine = toGlyph 0XEF18
remixMapPinUserFill = toGlyph 0XEF19
remixMapPinUserLine = toGlyph 0XEF1A
remixMarkPenFill = toGlyph 0XEF1B
remixMarkPenLine = toGlyph 0XEF1C
remixMarkdownFill = toGlyph 0XEF1D
remixMarkdownLine = toGlyph 0XEF1E
remixMarkupFill = toGlyph 0XEF1F
remixMarkupLine = toGlyph 0XEF20
remixMastercardFill = toGlyph 0XEF21
remixMastercardLine = toGlyph 0XEF22
remixMastodonFill = toGlyph 0XEF23
remixMastodonLine = toGlyph 0XEF24
remixMedal2Fill = toGlyph 0XEF25
remixMedal2Line = toGlyph 0XEF26
remixMedalFill = toGlyph 0XEF27
remixMedalLine = toGlyph 0XEF28
remixMedicineBottleFill = toGlyph 0XEF29
remixMedicineBottleLine = toGlyph 0XEF2A
remixMediumFill = toGlyph 0XEF2B
remixMediumLine = toGlyph 0XEF2C
remixMenFill = toGlyph 0XEF2D
remixMenLine = toGlyph 0XEF2E
remixMentalHealthFill = toGlyph 0XEF2F
remixMentalHealthLine = toGlyph 0XEF30
remixMenu2Fill = toGlyph 0XEF31
remixMenu2Line = toGlyph 0XEF32
remixMenu3Fill = toGlyph 0XEF33
remixMenu3Line = toGlyph 0XEF34
remixMenu4Fill = toGlyph 0XEF35
remixMenu4Line = toGlyph 0XEF36
remixMenu5Fill = toGlyph 0XEF37
remixMenu5Line = toGlyph 0XEF38
remixMenuAddFill = toGlyph 0XEF39
remixMenuAddLine = toGlyph 0XEF3A
remixMenuFill = toGlyph 0XEF3B
remixMenuFoldFill = toGlyph 0XEF3C
remixMenuFoldLine = toGlyph 0XEF3D
remixMenuLine = toGlyph 0XEF3E
remixMenuUnfoldFill = toGlyph 0XEF3F
remixMenuUnfoldLine = toGlyph 0XEF40
remixMergeCellsHorizontal = toGlyph 0XEF41
remixMergeCellsVertical = toGlyph 0XEF42
remixMessage2Fill = toGlyph 0XEF43
remixMessage2Line = toGlyph 0XEF44
remixMessage3Fill = toGlyph 0XEF45
remixMessage3Line = toGlyph 0XEF46
remixMessageFill = toGlyph 0XEF47
remixMessageLine = toGlyph 0XEF48
remixMessengerFill = toGlyph 0XEF49
remixMessengerLine = toGlyph 0XEF4A
remixMeteorFill = toGlyph 0XEF4B
remixMeteorLine = toGlyph 0XEF4C
remixMic2Fill = toGlyph 0XEF4D
remixMic2Line = toGlyph 0XEF4E
remixMicFill = toGlyph 0XEF4F
remixMicLine = toGlyph 0XEF50
remixMicOffFill = toGlyph 0XEF51
remixMicOffLine = toGlyph 0XEF52
remixMickeyFill = toGlyph 0XEF53
remixMickeyLine = toGlyph 0XEF54
remixMicroscopeFill = toGlyph 0XEF55
remixMicroscopeLine = toGlyph 0XEF56
remixMicrosoftFill = toGlyph 0XEF57
remixMicrosoftLine = toGlyph 0XEF58
remixMindMap = toGlyph 0XEF59
remixMiniProgramFill = toGlyph 0XEF5A
remixMiniProgramLine = toGlyph 0XEF5B
remixMistFill = toGlyph 0XEF5C
remixMistLine = toGlyph 0XEF5D
remixMoneyCnyBoxFill = toGlyph 0XEF5E
remixMoneyCnyBoxLine = toGlyph 0XEF5F
remixMoneyCnyCircleFill = toGlyph 0XEF60
remixMoneyCnyCircleLine = toGlyph 0XEF61
remixMoneyDollarBoxFill = toGlyph 0XEF62
remixMoneyDollarBoxLine = toGlyph 0XEF63
remixMoneyDollarCircleFill = toGlyph 0XEF64
remixMoneyDollarCircleLine = toGlyph 0XEF65
remixMoneyEuroBoxFill = toGlyph 0XEF66
remixMoneyEuroBoxLine = toGlyph 0XEF67
remixMoneyEuroCircleFill = toGlyph 0XEF68
remixMoneyEuroCircleLine = toGlyph 0XEF69
remixMoneyPoundBoxFill = toGlyph 0XEF6A
remixMoneyPoundBoxLine = toGlyph 0XEF6B
remixMoneyPoundCircleFill = toGlyph 0XEF6C
remixMoneyPoundCircleLine = toGlyph 0XEF6D
remixMoonClearFill = toGlyph 0XEF6E
remixMoonClearLine = toGlyph 0XEF6F
remixMoonCloudyFill = toGlyph 0XEF70
remixMoonCloudyLine = toGlyph 0XEF71
remixMoonFill = toGlyph 0XEF72
remixMoonFoggyFill = toGlyph 0XEF73
remixMoonFoggyLine = toGlyph 0XEF74
remixMoonLine = toGlyph 0XEF75
remixMore2Fill = toGlyph 0XEF76
remixMore2Line = toGlyph 0XEF77
remixMoreFill = toGlyph 0XEF78
remixMoreLine = toGlyph 0XEF79
remixMotorbikeFill = toGlyph 0XEF7A
remixMotorbikeLine = toGlyph 0XEF7B
remixMouseFill = toGlyph 0XEF7C
remixMouseLine = toGlyph 0XEF7D
remixMovie2Fill = toGlyph 0XEF7E
remixMovie2Line = toGlyph 0XEF7F
remixMovieFill = toGlyph 0XEF80
remixMovieLine = toGlyph 0XEF81
remixMusic2Fill = toGlyph 0XEF82
remixMusic2Line = toGlyph 0XEF83
remixMusicFill = toGlyph 0XEF84
remixMusicLine = toGlyph 0XEF85
remixMvFill = toGlyph 0XEF86
remixMvLine = toGlyph 0XEF87
remixNavigationFill = toGlyph 0XEF88
remixNavigationLine = toGlyph 0XEF89
remixNeteaseCloudMusicFill = toGlyph 0XEF8A
remixNeteaseCloudMusicLine = toGlyph 0XEF8B
remixNetflixFill = toGlyph 0XEF8C
remixNetflixLine = toGlyph 0XEF8D
remixNewspaperFill = toGlyph 0XEF8E
remixNewspaperLine = toGlyph 0XEF8F
remixNodeTree = toGlyph 0XEF90
remixNotification2Fill = toGlyph 0XEF91
remixNotification2Line = toGlyph 0XEF92
remixNotification3Fill = toGlyph 0XEF93
remixNotification3Line = toGlyph 0XEF94
remixNotification4Fill = toGlyph 0XEF95
remixNotification4Line = toGlyph 0XEF96
remixNotificationBadgeFill = toGlyph 0XEF97
remixNotificationBadgeLine = toGlyph 0XEF98
remixNotificationFill = toGlyph 0XEF99
remixNotificationLine = toGlyph 0XEF9A
remixNotificationOffFill = toGlyph 0XEF9B
remixNotificationOffLine = toGlyph 0XEF9C
remixNpmjsFill = toGlyph 0XEF9D
remixNpmjsLine = toGlyph 0XEF9E
remixNumber0 = toGlyph 0XEF9F
remixNumber1 = toGlyph 0XEFA0
remixNumber2 = toGlyph 0XEFA1
remixNumber3 = toGlyph 0XEFA2
remixNumber4 = toGlyph 0XEFA3
remixNumber5 = toGlyph 0XEFA4
remixNumber6 = toGlyph 0XEFA5
remixNumber7 = toGlyph 0XEFA6
remixNumber8 = toGlyph 0XEFA7
remixNumber9 = toGlyph 0XEFA8
remixNumbersFill = toGlyph 0XEFA9
remixNumbersLine = toGlyph 0XEFAA
remixNurseFill = toGlyph 0XEFAB
remixNurseLine = toGlyph 0XEFAC
remixOilFill = toGlyph 0XEFAD
remixOilLine = toGlyph 0XEFAE
remixOmega = toGlyph 0XEFAF
remixOpenArmFill = toGlyph 0XEFB0
remixOpenArmLine = toGlyph 0XEFB1
remixOpenSourceFill = toGlyph 0XEFB2
remixOpenSourceLine = toGlyph 0XEFB3
remixOperaFill = toGlyph 0XEFB4
remixOperaLine = toGlyph 0XEFB5
remixOrderPlayFill = toGlyph 0XEFB6
remixOrderPlayLine = toGlyph 0XEFB7
remixOrganizationChart = toGlyph 0XEFB8
remixOutlet2Fill = toGlyph 0XEFB9
remixOutlet2Line = toGlyph 0XEFBA
remixOutletFill = toGlyph 0XEFBB
remixOutletLine = toGlyph 0XEFBC
remixPageSeparator = toGlyph 0XEFBD
remixPagesFill = toGlyph 0XEFBE
remixPagesLine = toGlyph 0XEFBF
remixPaintBrushFill = toGlyph 0XEFC0
remixPaintBrushLine = toGlyph 0XEFC1
remixPaintFill = toGlyph 0XEFC2
remixPaintLine = toGlyph 0XEFC3
remixPaletteFill = toGlyph 0XEFC4
remixPaletteLine = toGlyph 0XEFC5
remixPantoneFill = toGlyph 0XEFC6
remixPantoneLine = toGlyph 0XEFC7
remixParagraph = toGlyph 0XEFC8
remixParentFill = toGlyph 0XEFC9
remixParentLine = toGlyph 0XEFCA
remixParenthesesFill = toGlyph 0XEFCB
remixParenthesesLine = toGlyph 0XEFCC
remixParkingBoxFill = toGlyph 0XEFCD
remixParkingBoxLine = toGlyph 0XEFCE
remixParkingFill = toGlyph 0XEFCF
remixParkingLine = toGlyph 0XEFD0
remixPassportFill = toGlyph 0XEFD1
remixPassportLine = toGlyph 0XEFD2
remixPatreonFill = toGlyph 0XEFD3
remixPatreonLine = toGlyph 0XEFD4
remixPauseCircleFill = toGlyph 0XEFD5
remixPauseCircleLine = toGlyph 0XEFD6
remixPauseFill = toGlyph 0XEFD7
remixPauseLine = toGlyph 0XEFD8
remixPauseMiniFill = toGlyph 0XEFD9
remixPauseMiniLine = toGlyph 0XEFDA
remixPaypalFill = toGlyph 0XEFDB
remixPaypalLine = toGlyph 0XEFDC
remixPenNibFill = toGlyph 0XEFDD
remixPenNibLine = toGlyph 0XEFDE
remixPencilFill = toGlyph 0XEFDF
remixPencilLine = toGlyph 0XEFE0
remixPencilRuler2Fill = toGlyph 0XEFE1
remixPencilRuler2Line = toGlyph 0XEFE2
remixPencilRulerFill = toGlyph 0XEFE3
remixPencilRulerLine = toGlyph 0XEFE4
remixPercentFill = toGlyph 0XEFE5
remixPercentLine = toGlyph 0XEFE6
remixPhoneCameraFill = toGlyph 0XEFE7
remixPhoneCameraLine = toGlyph 0XEFE8
remixPhoneFill = toGlyph 0XEFE9
remixPhoneFindFill = toGlyph 0XEFEA
remixPhoneFindLine = toGlyph 0XEFEB
remixPhoneLine = toGlyph 0XEFEC
remixPhoneLockFill = toGlyph 0XEFED
remixPhoneLockLine = toGlyph 0XEFEE
remixPictureInPicture2Fill = toGlyph 0XEFEF
remixPictureInPicture2Line = toGlyph 0XEFF0
remixPictureInPictureExitFill = toGlyph 0XEFF1
remixPictureInPictureExitLine = toGlyph 0XEFF2
remixPictureInPictureFill = toGlyph 0XEFF3
remixPictureInPictureLine = toGlyph 0XEFF4
remixPieChart2Fill = toGlyph 0XEFF5
remixPieChart2Line = toGlyph 0XEFF6
remixPieChartBoxFill = toGlyph 0XEFF7
remixPieChartBoxLine = toGlyph 0XEFF8
remixPieChartFill = toGlyph 0XEFF9
remixPieChartLine = toGlyph 0XEFFA
remixPinDistanceFill = toGlyph 0XEFFB
remixPinDistanceLine = toGlyph 0XEFFC
remixPingPongFill = toGlyph 0XEFFD
remixPingPongLine = toGlyph 0XEFFE
remixPinterestFill = toGlyph 0XEFFF
remixPinterestLine = toGlyph 0XF000
remixPinyinInput = toGlyph 0XF001
remixPixelfedFill = toGlyph 0XF002
remixPixelfedLine = toGlyph 0XF003
remixPlaneFill = toGlyph 0XF004
remixPlaneLine = toGlyph 0XF005
remixPlantFill = toGlyph 0XF006
remixPlantLine = toGlyph 0XF007
remixPlayCircleFill = toGlyph 0XF008
remixPlayCircleLine = toGlyph 0XF009
remixPlayFill = toGlyph 0XF00A
remixPlayLine = toGlyph 0XF00B
remixPlayList2Fill = toGlyph 0XF00C
remixPlayList2Line = toGlyph 0XF00D
remixPlayListAddFill = toGlyph 0XF00E
remixPlayListAddLine = toGlyph 0XF00F
remixPlayListFill = toGlyph 0XF010
remixPlayListLine = toGlyph 0XF011
remixPlayMiniFill = toGlyph 0XF012
remixPlayMiniLine = toGlyph 0XF013
remixPlaystationFill = toGlyph 0XF014
remixPlaystationLine = toGlyph 0XF015
remixPlug2Fill = toGlyph 0XF016
remixPlug2Line = toGlyph 0XF017
remixPlugFill = toGlyph 0XF018
remixPlugLine = toGlyph 0XF019
remixPolaroid2Fill = toGlyph 0XF01A
remixPolaroid2Line = toGlyph 0XF01B
remixPolaroidFill = toGlyph 0XF01C
remixPolaroidLine = toGlyph 0XF01D
remixPoliceCarFill = toGlyph 0XF01E
remixPoliceCarLine = toGlyph 0XF01F
remixPriceTag2Fill = toGlyph 0XF020
remixPriceTag2Line = toGlyph 0XF021
remixPriceTag3Fill = toGlyph 0XF022
remixPriceTag3Line = toGlyph 0XF023
remixPriceTagFill = toGlyph 0XF024
remixPriceTagLine = toGlyph 0XF025
remixPrinterCloudFill = toGlyph 0XF026
remixPrinterCloudLine = toGlyph 0XF027
remixPrinterFill = toGlyph 0XF028
remixPrinterLine = toGlyph 0XF029
remixProductHuntFill = toGlyph 0XF02A
remixProductHuntLine = toGlyph 0XF02B
remixProfileFill = toGlyph 0XF02C
remixProfileLine = toGlyph 0XF02D
remixProjector2Fill = toGlyph 0XF02E
remixProjector2Line = toGlyph 0XF02F
remixProjectorFill = toGlyph 0XF030
remixProjectorLine = toGlyph 0XF031
remixPsychotherapyFill = toGlyph 0XF032
remixPsychotherapyLine = toGlyph 0XF033
remixPulseFill = toGlyph 0XF034
remixPulseLine = toGlyph 0XF035
remixPushpin2Fill = toGlyph 0XF036
remixPushpin2Line = toGlyph 0XF037
remixPushpinFill = toGlyph 0XF038
remixPushpinLine = toGlyph 0XF039
remixQqFill = toGlyph 0XF03A
remixQqLine = toGlyph 0XF03B
remixQrCodeFill = toGlyph 0XF03C
remixQrCodeLine = toGlyph 0XF03D
remixQrScan2Fill = toGlyph 0XF03E
remixQrScan2Line = toGlyph 0XF03F
remixQrScanFill = toGlyph 0XF040
remixQrScanLine = toGlyph 0XF041
remixQuestionAnswerFill = toGlyph 0XF042
remixQuestionAnswerLine = toGlyph 0XF043
remixQuestionFill = toGlyph 0XF044
remixQuestionLine = toGlyph 0XF045
remixQuestionMark = toGlyph 0XF046
remixQuestionnaireFill = toGlyph 0XF047
remixQuestionnaireLine = toGlyph 0XF048
remixQuillPenFill = toGlyph 0XF049
remixQuillPenLine = toGlyph 0XF04A
remixRadarFill = toGlyph 0XF04B
remixRadarLine = toGlyph 0XF04C
remixRadio2Fill = toGlyph 0XF04D
remixRadio2Line = toGlyph 0XF04E
remixRadioButtonFill = toGlyph 0XF04F
remixRadioButtonLine = toGlyph 0XF050
remixRadioFill = toGlyph 0XF051
remixRadioLine = toGlyph 0XF052
remixRainbowFill = toGlyph 0XF053
remixRainbowLine = toGlyph 0XF054
remixRainyFill = toGlyph 0XF055
remixRainyLine = toGlyph 0XF056
remixReactjsFill = toGlyph 0XF057
remixReactjsLine = toGlyph 0XF058
remixRecordCircleFill = toGlyph 0XF059
remixRecordCircleLine = toGlyph 0XF05A
remixRecordMailFill = toGlyph 0XF05B
remixRecordMailLine = toGlyph 0XF05C
remixRecycleFill = toGlyph 0XF05D
remixRecycleLine = toGlyph 0XF05E
remixRedPacketFill = toGlyph 0XF05F
remixRedPacketLine = toGlyph 0XF060
remixRedditFill = toGlyph 0XF061
remixRedditLine = toGlyph 0XF062
remixRefreshFill = toGlyph 0XF063
remixRefreshLine = toGlyph 0XF064
remixRefund2Fill = toGlyph 0XF065
remixRefund2Line = toGlyph 0XF066
remixRefundFill = toGlyph 0XF067
remixRefundLine = toGlyph 0XF068
remixRegisteredFill = toGlyph 0XF069
remixRegisteredLine = toGlyph 0XF06A
remixRemixiconFill = toGlyph 0XF06B
remixRemixiconLine = toGlyph 0XF06C
remixRemoteControl2Fill = toGlyph 0XF06D
remixRemoteControl2Line = toGlyph 0XF06E
remixRemoteControlFill = toGlyph 0XF06F
remixRemoteControlLine = toGlyph 0XF070
remixRepeat2Fill = toGlyph 0XF071
remixRepeat2Line = toGlyph 0XF072
remixRepeatFill = toGlyph 0XF073
remixRepeatLine = toGlyph 0XF074
remixRepeatOneFill = toGlyph 0XF075
remixRepeatOneLine = toGlyph 0XF076
remixReplyAllFill = toGlyph 0XF077
remixReplyAllLine = toGlyph 0XF078
remixReplyFill = toGlyph 0XF079
remixReplyLine = toGlyph 0XF07A
remixReservedFill = toGlyph 0XF07B
remixReservedLine = toGlyph 0XF07C
remixRestTimeFill = toGlyph 0XF07D
remixRestTimeLine = toGlyph 0XF07E
remixRestartFill = toGlyph 0XF07F
remixRestartLine = toGlyph 0XF080
remixRestaurant2Fill = toGlyph 0XF081
remixRestaurant2Line = toGlyph 0XF082
remixRestaurantFill = toGlyph 0XF083
remixRestaurantLine = toGlyph 0XF084
remixRewindFill = toGlyph 0XF085
remixRewindLine = toGlyph 0XF086
remixRewindMiniFill = toGlyph 0XF087
remixRewindMiniLine = toGlyph 0XF088
remixRhythmFill = toGlyph 0XF089
remixRhythmLine = toGlyph 0XF08A
remixRidingFill = toGlyph 0XF08B
remixRidingLine = toGlyph 0XF08C
remixRoadMapFill = toGlyph 0XF08D
remixRoadMapLine = toGlyph 0XF08E
remixRoadsterFill = toGlyph 0XF08F
remixRoadsterLine = toGlyph 0XF090
remixRobotFill = toGlyph 0XF091
remixRobotLine = toGlyph 0XF092
remixRocket2Fill = toGlyph 0XF093
remixRocket2Line = toGlyph 0XF094
remixRocketFill = toGlyph 0XF095
remixRocketLine = toGlyph 0XF096
remixRotateLockFill = toGlyph 0XF097
remixRotateLockLine = toGlyph 0XF098
remixRoundedCorner = toGlyph 0XF099
remixRouteFill = toGlyph 0XF09A
remixRouteLine = toGlyph 0XF09B
remixRouterFill = toGlyph 0XF09C
remixRouterLine = toGlyph 0XF09D
remixRssFill = toGlyph 0XF09E
remixRssLine = toGlyph 0XF09F
remixRuler2Fill = toGlyph 0XF0A0
remixRuler2Line = toGlyph 0XF0A1
remixRulerFill = toGlyph 0XF0A2
remixRulerLine = toGlyph 0XF0A3
remixRunFill = toGlyph 0XF0A4
remixRunLine = toGlyph 0XF0A5
remixSafariFill = toGlyph 0XF0A6
remixSafariLine = toGlyph 0XF0A7
remixSafe2Fill = toGlyph 0XF0A8
remixSafe2Line = toGlyph 0XF0A9
remixSafeFill = toGlyph 0XF0AA
remixSafeLine = toGlyph 0XF0AB
remixSailboatFill = toGlyph 0XF0AC
remixSailboatLine = toGlyph 0XF0AD
remixSave2Fill = toGlyph 0XF0AE
remixSave2Line = toGlyph 0XF0AF
remixSave3Fill = toGlyph 0XF0B0
remixSave3Line = toGlyph 0XF0B1
remixSaveFill = toGlyph 0XF0B2
remixSaveLine = toGlyph 0XF0B3
remixScales2Fill = toGlyph 0XF0B4
remixScales2Line = toGlyph 0XF0B5
remixScales3Fill = toGlyph 0XF0B6
remixScales3Line = toGlyph 0XF0B7
remixScalesFill = toGlyph 0XF0B8
remixScalesLine = toGlyph 0XF0B9
remixScan2Fill = toGlyph 0XF0BA
remixScan2Line = toGlyph 0XF0BB
remixScanFill = toGlyph 0XF0BC
remixScanLine = toGlyph 0XF0BD
remixScissors2Fill = toGlyph 0XF0BE
remixScissors2Line = toGlyph 0XF0BF
remixScissorsCutFill = toGlyph 0XF0C0
remixScissorsCutLine = toGlyph 0XF0C1
remixScissorsFill = toGlyph 0XF0C2
remixScissorsLine = toGlyph 0XF0C3
remixScreenshot2Fill = toGlyph 0XF0C4
remixScreenshot2Line = toGlyph 0XF0C5
remixScreenshotFill = toGlyph 0XF0C6
remixScreenshotLine = toGlyph 0XF0C7
remixSdCardFill = toGlyph 0XF0C8
remixSdCardLine = toGlyph 0XF0C9
remixSdCardMiniFill = toGlyph 0XF0CA
remixSdCardMiniLine = toGlyph 0XF0CB
remixSearch2Fill = toGlyph 0XF0CC
remixSearch2Line = toGlyph 0XF0CD
remixSearchEyeFill = toGlyph 0XF0CE
remixSearchEyeLine = toGlyph 0XF0CF
remixSearchFill = toGlyph 0XF0D0
remixSearchLine = toGlyph 0XF0D1
remixSecurePaymentFill = toGlyph 0XF0D2
remixSecurePaymentLine = toGlyph 0XF0D3
remixSeedlingFill = toGlyph 0XF0D4
remixSeedlingLine = toGlyph 0XF0D5
remixSendBackward = toGlyph 0XF0D6
remixSendPlane2Fill = toGlyph 0XF0D7
remixSendPlane2Line = toGlyph 0XF0D8
remixSendPlaneFill = toGlyph 0XF0D9
remixSendPlaneLine = toGlyph 0XF0DA
remixSendToBack = toGlyph 0XF0DB
remixSensorFill = toGlyph 0XF0DC
remixSensorLine = toGlyph 0XF0DD
remixSeparator = toGlyph 0XF0DE
remixServerFill = toGlyph 0XF0DF
remixServerLine = toGlyph 0XF0E0
remixServiceFill = toGlyph 0XF0E1
remixServiceLine = toGlyph 0XF0E2
remixSettings2Fill = toGlyph 0XF0E3
remixSettings2Line = toGlyph 0XF0E4
remixSettings3Fill = toGlyph 0XF0E5
remixSettings3Line = toGlyph 0XF0E6
remixSettings4Fill = toGlyph 0XF0E7
remixSettings4Line = toGlyph 0XF0E8
remixSettings5Fill = toGlyph 0XF0E9
remixSettings5Line = toGlyph 0XF0EA
remixSettings6Fill = toGlyph 0XF0EB
remixSettings6Line = toGlyph 0XF0EC
remixSettingsFill = toGlyph 0XF0ED
remixSettingsLine = toGlyph 0XF0EE
remixShape2Fill = toGlyph 0XF0EF
remixShape2Line = toGlyph 0XF0F0
remixShapeFill = toGlyph 0XF0F1
remixShapeLine = toGlyph 0XF0F2
remixShareBoxFill = toGlyph 0XF0F3
remixShareBoxLine = toGlyph 0XF0F4
remixShareCircleFill = toGlyph 0XF0F5
remixShareCircleLine = toGlyph 0XF0F6
remixShareFill = toGlyph 0XF0F7
remixShareForward2Fill = toGlyph 0XF0F8
remixShareForward2Line = toGlyph 0XF0F9
remixShareForwardBoxFill = toGlyph 0XF0FA
remixShareForwardBoxLine = toGlyph 0XF0FB
remixShareForwardFill = toGlyph 0XF0FC
remixShareForwardLine = toGlyph 0XF0FD
remixShareLine = toGlyph 0XF0FE
remixShieldCheckFill = toGlyph 0XF0FF
remixShieldCheckLine = toGlyph 0XF100
remixShieldCrossFill = toGlyph 0XF101
remixShieldCrossLine = toGlyph 0XF102
remixShieldFill = toGlyph 0XF103
remixShieldFlashFill = toGlyph 0XF104
remixShieldFlashLine = toGlyph 0XF105
remixShieldKeyholeFill = toGlyph 0XF106
remixShieldKeyholeLine = toGlyph 0XF107
remixShieldLine = toGlyph 0XF108
remixShieldStarFill = toGlyph 0XF109
remixShieldStarLine = toGlyph 0XF10A
remixShieldUserFill = toGlyph 0XF10B
remixShieldUserLine = toGlyph 0XF10C
remixShip2Fill = toGlyph 0XF10D
remixShip2Line = toGlyph 0XF10E
remixShipFill = toGlyph 0XF10F
remixShipLine = toGlyph 0XF110
remixShirtFill = toGlyph 0XF111
remixShirtLine = toGlyph 0XF112
remixShoppingBag2Fill = toGlyph 0XF113
remixShoppingBag2Line = toGlyph 0XF114
remixShoppingBag3Fill = toGlyph 0XF115
remixShoppingBag3Line = toGlyph 0XF116
remixShoppingBagFill = toGlyph 0XF117
remixShoppingBagLine = toGlyph 0XF118
remixShoppingBasket2Fill = toGlyph 0XF119
remixShoppingBasket2Line = toGlyph 0XF11A
remixShoppingBasketFill = toGlyph 0XF11B
remixShoppingBasketLine = toGlyph 0XF11C
remixShoppingCart2Fill = toGlyph 0XF11D
remixShoppingCart2Line = toGlyph 0XF11E
remixShoppingCartFill = toGlyph 0XF11F
remixShoppingCartLine = toGlyph 0XF120
remixShowersFill = toGlyph 0XF121
remixShowersLine = toGlyph 0XF122
remixShuffleFill = toGlyph 0XF123
remixShuffleLine = toGlyph 0XF124
remixShutDownFill = toGlyph 0XF125
remixShutDownLine = toGlyph 0XF126
remixSideBarFill = toGlyph 0XF127
remixSideBarLine = toGlyph 0XF128
remixSignalTowerFill = toGlyph 0XF129
remixSignalTowerLine = toGlyph 0XF12A
remixSignalWifi1Fill = toGlyph 0XF12B
remixSignalWifi1Line = toGlyph 0XF12C
remixSignalWifi2Fill = toGlyph 0XF12D
remixSignalWifi2Line = toGlyph 0XF12E
remixSignalWifi3Fill = toGlyph 0XF12F
remixSignalWifi3Line = toGlyph 0XF130
remixSignalWifiErrorFill = toGlyph 0XF131
remixSignalWifiErrorLine = toGlyph 0XF132
remixSignalWifiFill = toGlyph 0XF133
remixSignalWifiLine = toGlyph 0XF134
remixSignalWifiOffFill = toGlyph 0XF135
remixSignalWifiOffLine = toGlyph 0XF136
remixSimCard2Fill = toGlyph 0XF137
remixSimCard2Line = toGlyph 0XF138
remixSimCardFill = toGlyph 0XF139
remixSimCardLine = toGlyph 0XF13A
remixSingleQuotesL = toGlyph 0XF13B
remixSingleQuotesR = toGlyph 0XF13C
remixSipFill = toGlyph 0XF13D
remixSipLine = toGlyph 0XF13E
remixSkipBackFill = toGlyph 0XF13F
remixSkipBackLine = toGlyph 0XF140
remixSkipBackMiniFill = toGlyph 0XF141
remixSkipBackMiniLine = toGlyph 0XF142
remixSkipForwardFill = toGlyph 0XF143
remixSkipForwardLine = toGlyph 0XF144
remixSkipForwardMiniFill = toGlyph 0XF145
remixSkipForwardMiniLine = toGlyph 0XF146
remixSkull2Fill = toGlyph 0XF147
remixSkull2Line = toGlyph 0XF148
remixSkullFill = toGlyph 0XF149
remixSkullLine = toGlyph 0XF14A
remixSkypeFill = toGlyph 0XF14B
remixSkypeLine = toGlyph 0XF14C
remixSlackFill = toGlyph 0XF14D
remixSlackLine = toGlyph 0XF14E
remixSliceFill = toGlyph 0XF14F
remixSliceLine = toGlyph 0XF150
remixSlideshow2Fill = toGlyph 0XF151
remixSlideshow2Line = toGlyph 0XF152
remixSlideshow3Fill = toGlyph 0XF153
remixSlideshow3Line = toGlyph 0XF154
remixSlideshow4Fill = toGlyph 0XF155
remixSlideshow4Line = toGlyph 0XF156
remixSlideshowFill = toGlyph 0XF157
remixSlideshowLine = toGlyph 0XF158
remixSmartphoneFill = toGlyph 0XF159
remixSmartphoneLine = toGlyph 0XF15A
remixSnapchatFill = toGlyph 0XF15B
remixSnapchatLine = toGlyph 0XF15C
remixSnowyFill = toGlyph 0XF15D
remixSnowyLine = toGlyph 0XF15E
remixSortAsc = toGlyph 0XF15F
remixSortDesc = toGlyph 0XF160
remixSoundModuleFill = toGlyph 0XF161
remixSoundModuleLine = toGlyph 0XF162
remixSoundcloudFill = toGlyph 0XF163
remixSoundcloudLine = toGlyph 0XF164
remixSpaceShipFill = toGlyph 0XF165
remixSpaceShipLine = toGlyph 0XF166
remixSpace = toGlyph 0XF167
remixSpam2Fill = toGlyph 0XF168
remixSpam2Line = toGlyph 0XF169
remixSpam3Fill = toGlyph 0XF16A
remixSpam3Line = toGlyph 0XF16B
remixSpamFill = toGlyph 0XF16C
remixSpamLine = toGlyph 0XF16D
remixSpeaker2Fill = toGlyph 0XF16E
remixSpeaker2Line = toGlyph 0XF16F
remixSpeaker3Fill = toGlyph 0XF170
remixSpeaker3Line = toGlyph 0XF171
remixSpeakerFill = toGlyph 0XF172
remixSpeakerLine = toGlyph 0XF173
remixSpectrumFill = toGlyph 0XF174
remixSpectrumLine = toGlyph 0XF175
remixSpeedFill = toGlyph 0XF176
remixSpeedLine = toGlyph 0XF177
remixSpeedMiniFill = toGlyph 0XF178
remixSpeedMiniLine = toGlyph 0XF179
remixSplitCellsHorizontal = toGlyph 0XF17A
remixSplitCellsVertical = toGlyph 0XF17B
remixSpotifyFill = toGlyph 0XF17C
remixSpotifyLine = toGlyph 0XF17D
remixSpyFill = toGlyph 0XF17E
remixSpyLine = toGlyph 0XF17F
remixStackFill = toGlyph 0XF180
remixStackLine = toGlyph 0XF181
remixStackOverflowFill = toGlyph 0XF182
remixStackOverflowLine = toGlyph 0XF183
remixStackshareFill = toGlyph 0XF184
remixStackshareLine = toGlyph 0XF185
remixStarFill = toGlyph 0XF186
remixStarHalfFill = toGlyph 0XF187
remixStarHalfLine = toGlyph 0XF188
remixStarHalfSFill = toGlyph 0XF189
remixStarHalfSLine = toGlyph 0XF18A
remixStarLine = toGlyph 0XF18B
remixStarSFill = toGlyph 0XF18C
remixStarSLine = toGlyph 0XF18D
remixStarSmileFill = toGlyph 0XF18E
remixStarSmileLine = toGlyph 0XF18F
remixSteamFill = toGlyph 0XF190
remixSteamLine = toGlyph 0XF191
remixSteering2Fill = toGlyph 0XF192
remixSteering2Line = toGlyph 0XF193
remixSteeringFill = toGlyph 0XF194
remixSteeringLine = toGlyph 0XF195
remixStethoscopeFill = toGlyph 0XF196
remixStethoscopeLine = toGlyph 0XF197
remixStickyNote2Fill = toGlyph 0XF198
remixStickyNote2Line = toGlyph 0XF199
remixStickyNoteFill = toGlyph 0XF19A
remixStickyNoteLine = toGlyph 0XF19B
remixStockFill = toGlyph 0XF19C
remixStockLine = toGlyph 0XF19D
remixStopCircleFill = toGlyph 0XF19E
remixStopCircleLine = toGlyph 0XF19F
remixStopFill = toGlyph 0XF1A0
remixStopLine = toGlyph 0XF1A1
remixStopMiniFill = toGlyph 0XF1A2
remixStopMiniLine = toGlyph 0XF1A3
remixStore2Fill = toGlyph 0XF1A4
remixStore2Line = toGlyph 0XF1A5
remixStore3Fill = toGlyph 0XF1A6
remixStore3Line = toGlyph 0XF1A7
remixStoreFill = toGlyph 0XF1A8
remixStoreLine = toGlyph 0XF1A9
remixStrikethrough2 = toGlyph 0XF1AA
remixStrikethrough = toGlyph 0XF1AB
remixSubscript2 = toGlyph 0XF1AC
remixSubscript = toGlyph 0XF1AD
remixSubtractFill = toGlyph 0XF1AE
remixSubtractLine = toGlyph 0XF1AF
remixSubwayFill = toGlyph 0XF1B0
remixSubwayLine = toGlyph 0XF1B1
remixSubwayWifiFill = toGlyph 0XF1B2
remixSubwayWifiLine = toGlyph 0XF1B3
remixSuitcase2Fill = toGlyph 0XF1B4
remixSuitcase2Line = toGlyph 0XF1B5
remixSuitcase3Fill = toGlyph 0XF1B6
remixSuitcase3Line = toGlyph 0XF1B7
remixSuitcaseFill = toGlyph 0XF1B8
remixSuitcaseLine = toGlyph 0XF1B9
remixSunCloudyFill = toGlyph 0XF1BA
remixSunCloudyLine = toGlyph 0XF1BB
remixSunFill = toGlyph 0XF1BC
remixSunFoggyFill = toGlyph 0XF1BD
remixSunFoggyLine = toGlyph 0XF1BE
remixSunLine = toGlyph 0XF1BF
remixSuperscript2 = toGlyph 0XF1C0
remixSuperscript = toGlyph 0XF1C1
remixSurgicalMaskFill = toGlyph 0XF1C2
remixSurgicalMaskLine = toGlyph 0XF1C3
remixSurroundSoundFill = toGlyph 0XF1C4
remixSurroundSoundLine = toGlyph 0XF1C5
remixSurveyFill = toGlyph 0XF1C6
remixSurveyLine = toGlyph 0XF1C7
remixSwapBoxFill = toGlyph 0XF1C8
remixSwapBoxLine = toGlyph 0XF1C9
remixSwapFill = toGlyph 0XF1CA
remixSwapLine = toGlyph 0XF1CB
remixSwitchFill = toGlyph 0XF1CC
remixSwitchLine = toGlyph 0XF1CD
remixSwordFill = toGlyph 0XF1CE
remixSwordLine = toGlyph 0XF1CF
remixSyringeFill = toGlyph 0XF1D0
remixSyringeLine = toGlyph 0XF1D1
remixTBoxFill = toGlyph 0XF1D2
remixTBoxLine = toGlyph 0XF1D3
remixTShirt2Fill = toGlyph 0XF1D4
remixTShirt2Line = toGlyph 0XF1D5
remixTShirtAirFill = toGlyph 0XF1D6
remixTShirtAirLine = toGlyph 0XF1D7
remixTShirtFill = toGlyph 0XF1D8
remixTShirtLine = toGlyph 0XF1D9
remixTable2 = toGlyph 0XF1DA
remixTableAltFill = toGlyph 0XF1DB
remixTableAltLine = toGlyph 0XF1DC
remixTableFill = toGlyph 0XF1DD
remixTableLine = toGlyph 0XF1DE
remixTabletFill = toGlyph 0XF1DF
remixTabletLine = toGlyph 0XF1E0
remixTakeawayFill = toGlyph 0XF1E1
remixTakeawayLine = toGlyph 0XF1E2
remixTaobaoFill = toGlyph 0XF1E3
remixTaobaoLine = toGlyph 0XF1E4
remixTapeFill = toGlyph 0XF1E5
remixTapeLine = toGlyph 0XF1E6
remixTaskFill = toGlyph 0XF1E7
remixTaskLine = toGlyph 0XF1E8
remixTaxiFill = toGlyph 0XF1E9
remixTaxiLine = toGlyph 0XF1EA
remixTaxiWifiFill = toGlyph 0XF1EB
remixTaxiWifiLine = toGlyph 0XF1EC
remixTeamFill = toGlyph 0XF1ED
remixTeamLine = toGlyph 0XF1EE
remixTelegramFill = toGlyph 0XF1EF
remixTelegramLine = toGlyph 0XF1F0
remixTempColdFill = toGlyph 0XF1F1
remixTempColdLine = toGlyph 0XF1F2
remixTempHotFill = toGlyph 0XF1F3
remixTempHotLine = toGlyph 0XF1F4
remixTerminalBoxFill = toGlyph 0XF1F5
remixTerminalBoxLine = toGlyph 0XF1F6
remixTerminalFill = toGlyph 0XF1F7
remixTerminalLine = toGlyph 0XF1F8
remixTerminalWindowFill = toGlyph 0XF1F9
remixTerminalWindowLine = toGlyph 0XF1FA
remixTestTubeFill = toGlyph 0XF1FB
remixTestTubeLine = toGlyph 0XF1FC
remixTextDirectionL = toGlyph 0XF1FD
remixTextDirectionR = toGlyph 0XF1FE
remixTextSpacing = toGlyph 0XF1FF
remixTextWrap = toGlyph 0XF200
remixText = toGlyph 0XF201
remixThermometerFill = toGlyph 0XF202
remixThermometerLine = toGlyph 0XF203
remixThumbDownFill = toGlyph 0XF204
remixThumbDownLine = toGlyph 0XF205
remixThumbUpFill = toGlyph 0XF206
remixThumbUpLine = toGlyph 0XF207
remixThunderstormsFill = toGlyph 0XF208
remixThunderstormsLine = toGlyph 0XF209
remixTicket2Fill = toGlyph 0XF20A
remixTicket2Line = toGlyph 0XF20B
remixTicketFill = toGlyph 0XF20C
remixTicketLine = toGlyph 0XF20D
remixTimeFill = toGlyph 0XF20E
remixTimeLine = toGlyph 0XF20F
remixTimer2Fill = toGlyph 0XF210
remixTimer2Line = toGlyph 0XF211
remixTimerFill = toGlyph 0XF212
remixTimerFlashFill = toGlyph 0XF213
remixTimerFlashLine = toGlyph 0XF214
remixTimerLine = toGlyph 0XF215
remixTodoFill = toGlyph 0XF216
remixTodoLine = toGlyph 0XF217
remixToggleFill = toGlyph 0XF218
remixToggleLine = toGlyph 0XF219
remixToolsFill = toGlyph 0XF21A
remixToolsLine = toGlyph 0XF21B
remixTornadoFill = toGlyph 0XF21C
remixTornadoLine = toGlyph 0XF21D
remixTrademarkFill = toGlyph 0XF21E
remixTrademarkLine = toGlyph 0XF21F
remixTrafficLightFill = toGlyph 0XF220
remixTrafficLightLine = toGlyph 0XF221
remixTrainFill = toGlyph 0XF222
remixTrainLine = toGlyph 0XF223
remixTrainWifiFill = toGlyph 0XF224
remixTrainWifiLine = toGlyph 0XF225
remixTranslate2 = toGlyph 0XF226
remixTranslate = toGlyph 0XF227
remixTravestiFill = toGlyph 0XF228
remixTravestiLine = toGlyph 0XF229
remixTreasureMapFill = toGlyph 0XF22A
remixTreasureMapLine = toGlyph 0XF22B
remixTrelloFill = toGlyph 0XF22C
remixTrelloLine = toGlyph 0XF22D
remixTrophyFill = toGlyph 0XF22E
remixTrophyLine = toGlyph 0XF22F
remixTruckFill = toGlyph 0XF230
remixTruckLine = toGlyph 0XF231
remixTumblrFill = toGlyph 0XF232
remixTumblrLine = toGlyph 0XF233
remixTv2Fill = toGlyph 0XF234
remixTv2Line = toGlyph 0XF235
remixTvFill = toGlyph 0XF236
remixTvLine = toGlyph 0XF237
remixTwitchFill = toGlyph 0XF238
remixTwitchLine = toGlyph 0XF239
remixTwitterFill = toGlyph 0XF23A
remixTwitterLine = toGlyph 0XF23B
remixTyphoonFill = toGlyph 0XF23C
remixTyphoonLine = toGlyph 0XF23D
remixUDiskFill = toGlyph 0XF23E
remixUDiskLine = toGlyph 0XF23F
remixUbuntuFill = toGlyph 0XF240
remixUbuntuLine = toGlyph 0XF241
remixUmbrellaFill = toGlyph 0XF242
remixUmbrellaLine = toGlyph 0XF243
remixUnderline = toGlyph 0XF244
remixUninstallFill = toGlyph 0XF245
remixUninstallLine = toGlyph 0XF246
remixUnsplashFill = toGlyph 0XF247
remixUnsplashLine = toGlyph 0XF248
remixUpload2Fill = toGlyph 0XF249
remixUpload2Line = toGlyph 0XF24A
remixUploadCloud2Fill = toGlyph 0XF24B
remixUploadCloud2Line = toGlyph 0XF24C
remixUploadCloudFill = toGlyph 0XF24D
remixUploadCloudLine = toGlyph 0XF24E
remixUploadFill = toGlyph 0XF24F
remixUploadLine = toGlyph 0XF250
remixUsbFill = toGlyph 0XF251
remixUsbLine = toGlyph 0XF252
remixUser2Fill = toGlyph 0XF253
remixUser2Line = toGlyph 0XF254
remixUser3Fill = toGlyph 0XF255
remixUser3Line = toGlyph 0XF256
remixUser4Fill = toGlyph 0XF257
remixUser4Line = toGlyph 0XF258
remixUser5Fill = toGlyph 0XF259
remixUser5Line = toGlyph 0XF25A
remixUser6Fill = toGlyph 0XF25B
remixUser6Line = toGlyph 0XF25C
remixUserAddFill = toGlyph 0XF25D
remixUserAddLine = toGlyph 0XF25E
remixUserFill = toGlyph 0XF25F
remixUserFollowFill = toGlyph 0XF260
remixUserFollowLine = toGlyph 0XF261
remixUserHeartFill = toGlyph 0XF262
remixUserHeartLine = toGlyph 0XF263
remixUserLine = toGlyph 0XF264
remixUserLocationFill = toGlyph 0XF265
remixUserLocationLine = toGlyph 0XF266
remixUserReceived2Fill = toGlyph 0XF267
remixUserReceived2Line = toGlyph 0XF268
remixUserReceivedFill = toGlyph 0XF269
remixUserReceivedLine = toGlyph 0XF26A
remixUserSearchFill = toGlyph 0XF26B
remixUserSearchLine = toGlyph 0XF26C
remixUserSettingsFill = toGlyph 0XF26D
remixUserSettingsLine = toGlyph 0XF26E
remixUserShared2Fill = toGlyph 0XF26F
remixUserShared2Line = toGlyph 0XF270
remixUserSharedFill = toGlyph 0XF271
remixUserSharedLine = toGlyph 0XF272
remixUserSmileFill = toGlyph 0XF273
remixUserSmileLine = toGlyph 0XF274
remixUserStarFill = toGlyph 0XF275
remixUserStarLine = toGlyph 0XF276
remixUserUnfollowFill = toGlyph 0XF277
remixUserUnfollowLine = toGlyph 0XF278
remixUserVoiceFill = toGlyph 0XF279
remixUserVoiceLine = toGlyph 0XF27A
remixVideoAddFill = toGlyph 0XF27B
remixVideoAddLine = toGlyph 0XF27C
remixVideoChatFill = toGlyph 0XF27D
remixVideoChatLine = toGlyph 0XF27E
remixVideoDownloadFill = toGlyph 0XF27F
remixVideoDownloadLine = toGlyph 0XF280
remixVideoFill = toGlyph 0XF281
remixVideoLine = toGlyph 0XF282
remixVideoUploadFill = toGlyph 0XF283
remixVideoUploadLine = toGlyph 0XF284
remixVidicon2Fill = toGlyph 0XF285
remixVidicon2Line = toGlyph 0XF286
remixVidiconFill = toGlyph 0XF287
remixVidiconLine = toGlyph 0XF288
remixVimeoFill = toGlyph 0XF289
remixVimeoLine = toGlyph 0XF28A
remixVipCrown2Fill = toGlyph 0XF28B
remixVipCrown2Line = toGlyph 0XF28C
remixVipCrownFill = toGlyph 0XF28D
remixVipCrownLine = toGlyph 0XF28E
remixVipDiamondFill = toGlyph 0XF28F
remixVipDiamondLine = toGlyph 0XF290
remixVipFill = toGlyph 0XF291
remixVipLine = toGlyph 0XF292
remixVirusFill = toGlyph 0XF293
remixVirusLine = toGlyph 0XF294
remixVisaFill = toGlyph 0XF295
remixVisaLine = toGlyph 0XF296
remixVoiceRecognitionFill = toGlyph 0XF297
remixVoiceRecognitionLine = toGlyph 0XF298
remixVoiceprintFill = toGlyph 0XF299
remixVoiceprintLine = toGlyph 0XF29A
remixVolumeDownFill = toGlyph 0XF29B
remixVolumeDownLine = toGlyph 0XF29C
remixVolumeMuteFill = toGlyph 0XF29D
remixVolumeMuteLine = toGlyph 0XF29E
remixVolumeOffVibrateFill = toGlyph 0XF29F
remixVolumeOffVibrateLine = toGlyph 0XF2A0
remixVolumeUpFill = toGlyph 0XF2A1
remixVolumeUpLine = toGlyph 0XF2A2
remixVolumeVibrateFill = toGlyph 0XF2A3
remixVolumeVibrateLine = toGlyph 0XF2A4
remixVuejsFill = toGlyph 0XF2A5
remixVuejsLine = toGlyph 0XF2A6
remixWalkFill = toGlyph 0XF2A7
remixWalkLine = toGlyph 0XF2A8
remixWallet2Fill = toGlyph 0XF2A9
remixWallet2Line = toGlyph 0XF2AA
remixWallet3Fill = toGlyph 0XF2AB
remixWallet3Line = toGlyph 0XF2AC
remixWalletFill = toGlyph 0XF2AD
remixWalletLine = toGlyph 0XF2AE
remixWaterFlashFill = toGlyph 0XF2AF
remixWaterFlashLine = toGlyph 0XF2B0
remixWebcamFill = toGlyph 0XF2B1
remixWebcamLine = toGlyph 0XF2B2
remixWechat2Fill = toGlyph 0XF2B3
remixWechat2Line = toGlyph 0XF2B4
remixWechatFill = toGlyph 0XF2B5
remixWechatLine = toGlyph 0XF2B6
remixWechatPayFill = toGlyph 0XF2B7
remixWechatPayLine = toGlyph 0XF2B8
remixWeiboFill = toGlyph 0XF2B9
remixWeiboLine = toGlyph 0XF2BA
remixWhatsappFill = toGlyph 0XF2BB
remixWhatsappLine = toGlyph 0XF2BC
remixWheelchairFill = toGlyph 0XF2BD
remixWheelchairLine = toGlyph 0XF2BE
remixWifiFill = toGlyph 0XF2BF
remixWifiLine = toGlyph 0XF2C0
remixWifiOffFill = toGlyph 0XF2C1
remixWifiOffLine = toGlyph 0XF2C2
remixWindow2Fill = toGlyph 0XF2C3
remixWindow2Line = toGlyph 0XF2C4
remixWindowFill = toGlyph 0XF2C5
remixWindowLine = toGlyph 0XF2C6
remixWindowsFill = toGlyph 0XF2C7
remixWindowsLine = toGlyph 0XF2C8
remixWindyFill = toGlyph 0XF2C9
remixWindyLine = toGlyph 0XF2CA
remixWirelessChargingFill = toGlyph 0XF2CB
remixWirelessChargingLine = toGlyph 0XF2CC
remixWomenFill = toGlyph 0XF2CD
remixWomenLine = toGlyph 0XF2CE
remixWubiInput = toGlyph 0XF2CF
remixXboxFill = toGlyph 0XF2D0
remixXboxLine = toGlyph 0XF2D1
remixXingFill = toGlyph 0XF2D2
remixXingLine = toGlyph 0XF2D3
remixYoutubeFill = toGlyph 0XF2D4
remixYoutubeLine = toGlyph 0XF2D5
remixZcoolFill = toGlyph 0XF2D6
remixZcoolLine = toGlyph 0XF2D7
remixZhihuFill = toGlyph 0XF2D8
remixZhihuLine = toGlyph 0XF2D9
remixZoomInFill = toGlyph 0XF2DA
remixZoomInLine = toGlyph 0XF2DB
remixZoomOutFill = toGlyph 0XF2DC
remixZoomOutLine = toGlyph 0XF2DD
remixZzzFill = toGlyph 0XF2DE
remixZzzLine = toGlyph 0XF2DF
